@@ -26,9 +26,9 @@
 #define DENEMO_TEXTEDITOR_TAG "texteditor"
 
 /* values for is_grace attribute of CHORD type */
-#define GRACE_SECTION (1<<0) /*Note is in grace section; For backward compatibility with old grace object types */
-#define GRACED_NOTE (1<<1) /*Note has been individually designated a grace note */
+#define GRACED_NOTE (1<<1) /*Note is an (appogiatura) grace note */
 #define ENDGRACE (1<<2) /*Note is last grace note in a group */
+#define ACCIACCATURA (1<<3) /*Note is an acciacatura grace note */
 
 
 typedef void (*GActionCallback) (GtkAction *action, gpointer data);
@@ -350,6 +350,7 @@ typedef struct DenemoKeymap
 
 }keymap;
 
+typedef enum { TYPESET_EXCERPT, TYPESET_MOVEMENT, TYPESET_ALL_MOVEMENTS} typeset_type;
 
 /**
  * DenemoPrefs holds information on user preferences. 
@@ -362,6 +363,13 @@ typedef struct DenemoPrefs
   GString *lilypath; /**< This is the executable or full path to the lilypond executable */
   GString *audioplayer; /**< This is used for playing audio files*/
   GString *fontspec; /**< Font specification usually Denemo as this has the required characters */
+  gboolean manualtypeset;/**< typeset on request, not continuously */
+  gint typesetrefresh;/**< ms between re-trying typeset */
+  gint typesettype;/**< what to re-typeset when not manual typeset */
+  gint firstmeasure;/**< first measure to typeset relative to the cursor when not manual typset */
+  gint firststaff;/**< first staff to typeset relative to the cursor when not manual typset */
+  gint lastmeasure;/**< last measure to typeset relative to the cursor when not manual typset */
+  gint laststaff;/**< last staff to typeset relative to the cursor when not manual typset */
   gboolean immediateplayback; /**< This options sends audio directly to synth as notes 
 				are being entered */
   gint pitchspellingchannel; /**< channel to use for feedback when entering extreme intervals via MIDI in, that may indicate an enharmonic error, 0 means no pitch spelling*/
@@ -448,6 +456,7 @@ typedef struct DenemoPrefs
   GString *lilyversion; /**< Lilypoind Version */
   GString *temperament; /**< Preferred temperament for tuning to */
   gboolean strictshortcuts; /**< Classic shortcut scheme, now deprecated */
+  gboolean menunavigation; /**< arrows and Escape work for menu navigation*/
   gboolean verboseshortcuts; /**< whether shortcuts are known by their gdk name e.g. period for . */
   
   gint resolution; /**< Resolution of exported selection in dpi */
@@ -467,6 +476,7 @@ typedef struct DenemoDirective
   GtkWidget *widget;  /**<  a button or menu item for accessing the directive for editing or actioning */
   gint gx, gy; /**< x and y offsets in pixels for the graphic */
   GString *graphic_name; /**< name of the graphic to be drawn the suffixes .svg or .png will be searched for */
+  GString *grob; /**<name of LilyPond grob which this directive creates. Use for tweaking positions, padding etc */
 
   /* warnings
      1) these values cannot be changed without bumping the denemo file format version
@@ -680,6 +690,7 @@ typedef struct DenemoScoreblock {
   guint32 id;/**< an id for this scoreblock generated from name, as a quick identifier */
   gint movement;/**< Which movement the scoreblock outputs, 0 = all movements. Only used for standard scoreblocks */
   gchar *partname; /**< Which part the scoreblock outputs, NULL = all parts. Only used for standard scoreblocks */
+  gboolean text_only;/**< TRUE if only the lilypond text exists for this widget - no widget structure to be refreshed */
 } DenemoScoreblock;
 
 
@@ -717,6 +728,30 @@ typedef struct DenemoAudio {
   gdouble volume;
   gpointer sndfile; /**< sndfile handle */
 } DenemoAudio;
+
+typedef enum DenemoTargetType {
+	TARGET_NONE = 0,
+	TARGET_OBJECT,
+	TARGET_CHORD,
+	TARGET_NOTE,
+	TARGET_SLUR,
+	TARGET_TIE,		
+	TARGET_CRESC,		
+	TARGET_DIM,		
+
+	//TARGET_,
+} DenemoTargetType;
+
+typedef struct DenemoTarget {
+  DenemoTargetType type;
+  gint mid_c_offset;
+  gint directivenum;
+  gint staffnum;
+  gint measurenum;
+  gint objnum;
+} DenemoTarget;
+
+
 /*
  *  DenemoScore structure representing a single movement of a piece of music.
  *  A movement corresponds with a single \score{} block in the LilyPond language
@@ -769,11 +804,12 @@ typedef struct DenemoScore
    * though they may be modified by side-effects of the drawing routines */
   // score thescore;
   staffnode *thescore;
-  
+  gint currentmovementnum;/**< position of this DenemoScore in the gui->movements list starting at 1 */
   staffnode *currentprimarystaff;
   staffnode *currentstaff;
   gint currentstaffnum;/**< start at 1 */
   measurenode *currentmeasure;
+  DenemoTarget target;/**< The target of a wysiwyg operation. This is currently only set by clicking on the print view window. */
   gint currentmeasurenum;/**< start at 1 */
   objnode *currentobject; /**< currentobject points to the note preceding the cursor when the
    * cursor is appending. == NULL only when currentmeasure is empty. */
@@ -869,9 +905,8 @@ typedef struct DenemoGUI
 
   gchar *xbm; /**< xbm representation of graphic bitmap from selected rectangle in print preview area*/
   gint xbm_width, xbm_height;/**< width and height of the xbm data */
-  GtkWidget *textwindow; /**< LilyPond output window */
-  GtkTextBuffer *textbuffer;   /**< buffer for LilyPond text */
-  GtkTextView *textview; /**< LilyPond output text view */
+
+  
   gchar *namespec;/**< A spec of which parts/movements to print */
   
 
@@ -890,7 +925,7 @@ typedef struct DenemoGUI
   scoreheader scoreheader;/*< Directives for the header block at the start of the score */
   paper paper;/*< Directives for the paper block of the score */
   GList *midi_events;/*< midi_events to be output at start of first track of each movement */
-
+	gboolean has_script;/*< true if there is a script to be run on loading the DenemoGUI from disk */
   GList *standard_scoreblocks; /**< List of automatically generated \score blocks for LilyPond output elements are DenemoScoreblock * */
   GList *custom_scoreblocks; /**< List of customized  \score blocks for LilyPond output, elements are DenemoScoreblock * */
   GtkWidget *score_layout; /**< The window in which custom_scoreblock widgets are placed */
@@ -987,6 +1022,9 @@ struct DenemoRoot
   GtkWidget *printvscrollbar;/**< scrollbar widget for printarea */
   GtkWidget *printhscrollbar;/**< scrollbar widget for printarea */
   GdkPixbuf *pixbuf;/**< print preview pixbuf */
+  GtkWidget *textwindow; /**< LilyPond output window */
+  GtkTextView *textview; /**< LilyPond output text view */
+  GtkTextBuffer *textbuffer;   /**< buffer for LilyPond text */
   /* window state */
   gint width;
   gint height;
