@@ -78,8 +78,10 @@ set_notehead (GtkAction *action, gpointer param)
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *combo;
-  gint i;
-  static GList *list = NULL;
+  GtkWidget *content_area;
+  static GList *list = NULL; //NOTE required for gtk<2.24
+  
+ gint i;
   if(!action) {
     if(  ((DenemoScriptParam *)param)->string && ((DenemoScriptParam *)param)->string->len) {
       insertnotehead (gui->si, ((DenemoScriptParam *)param)->string->str);
@@ -91,7 +93,6 @@ set_notehead (GtkAction *action, gpointer param)
       return;
     }
   }
-    
 
   if (!list)
     {
@@ -100,7 +101,7 @@ set_notehead (GtkAction *action, gpointer param)
 	  list = g_list_append (list, _(notehead[i]));
 	}
     }
-
+    
   dialog =
     gtk_dialog_new_with_buttons (_("Change Notehead"),
 				 GTK_WINDOW (Denemo.window),
@@ -110,35 +111,40 @@ set_notehead (GtkAction *action, gpointer param)
 				 GTK_STOCK_CANCEL, GTK_STOCK_CANCEL, NULL);
 
 
-
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   label = gtk_label_new (_("Select Notehead Type"));
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-		      label, TRUE, TRUE, 0);
-  gtk_widget_show (label);
-
+  gtk_container_add (GTK_CONTAINER (content_area), label);
+#if GTK_MAJOR_VERSION==3
+  combo = gtk_combo_box_text_new ();
+  for(i=0;i<G_N_ELEMENTS(notehead);i++)
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT(combo), notehead[i]);
+  gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);  
+#else
   combo = gtk_combo_new ();
   gtk_combo_set_popdown_strings (GTK_COMBO (combo), list);
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo)->entry), _(notehead[0]));
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), combo,
-		      TRUE, TRUE, 0);
-  gtk_widget_show (combo);
-
-
+  gtk_combo_box_set_active(GTK_COMBO (combo), 0);
+#endif
+  gtk_container_add (GTK_CONTAINER (content_area), combo);
   gtk_widget_grab_focus (combo);
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-  gtk_entry_set_activates_default (GTK_ENTRY (GTK_COMBO (combo)->entry),
-				   TRUE);
-  gtk_widget_show (dialog);
+  
+  gtk_widget_show_all (dialog);
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
+#if GTK_MAJOR_VERSION==3
+      gint num =     
+	gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+      insertnotehead (gui->si, notehead[num]);
+#else
       gchar *noteheadstring =
 	(gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (combo)->entry));
       insertnotehead (gui->si, noteheadstring);
+#endif
     }
-
-  gtk_widget_destroy (dialog);
+  gtk_widget_destroy(dialog);
   displayhelper (gui);
 }
