@@ -133,12 +133,12 @@ clef_change (DenemoGUI * gui, actiontype action)
 				 NULL);
 
 
+  GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   label = gtk_label_new (_("Select desired clef"));
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-		      label, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (content_area), label);
 
   list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
-  combobox = gtk_combo_box_new_with_model (GTK_TREE_MODEL (list_store));
+  combobox = gtk_combo_box_new_with_model (GTK_TREE_MODEL (list_store));//FIXME This looks like it could be made more simple to read by using someting like gtk_combo_text_box or something
 
   for (i = 0; i < (gint) G_N_ELEMENTS (clef_info); i++)
     {
@@ -158,9 +158,8 @@ clef_change (DenemoGUI * gui, actiontype action)
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combobox), renderer, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combobox),
 				 renderer, "text", COLUMN_NAME);
-
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-		      combobox, TRUE, TRUE, 0);
+  
+  gtk_container_add (GTK_CONTAINER (content_area), combobox);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
   gtk_widget_show_all (dialog);
