@@ -163,14 +163,19 @@ setcurrents (DenemoScore * si)
 void
 nudgerightward (DenemoGUI * gui)
 {
-  set_rightmeasurenum (gui->si);
-  while (gui->si->currentmeasurenum > gui->si->rightmeasurenum)
-    {
-      gui->si->leftmeasurenum++;
-      set_rightmeasurenum (gui->si);
-    }
-  find_leftmost_allcontexts (gui->si);
-  update_hscrollbar (gui);
+  if(set_rightmeasurenum (gui->si) || (gui->si->currentmeasurenum > gui->si->rightmeasurenum))
+  {
+		if(gui->si->currentmeasurenum > gui->si->rightmeasurenum) {
+			while (gui->si->currentmeasurenum > gui->si->rightmeasurenum)
+				{
+					gui->si->leftmeasurenum++;
+					set_rightmeasurenum (gui->si);
+				}
+
+		}
+		find_leftmost_allcontexts (gui->si);
+		update_hscrollbar (gui);	
+	}
 }
 
 /**
@@ -444,12 +449,12 @@ swapmovements (GtkAction *action, gpointer param)
     this->prev = prevv;
     prev->next = next;
     prev->prev = this;
-    gchar *str = g_strdup_printf("This movement is now number %d in the score", 1+g_list_index(gui->movements, gui->si));
+    gchar *str = g_strdup_printf(_("This movement is now number %d in the score"), 1+g_list_index(gui->movements, gui->si));
     infodialog(str);
     g_free(str);
     return TRUE;
   } else
-    warningdialog("There is no previous movement to swap with");
+    warningdialog(_("There is no previous movement to swap with"));
   return FALSE;
 }
 /**
@@ -471,7 +476,7 @@ swapstaffs (GtkAction *action, gpointer param)
 
 	temp = gui->si->currentstaff->data;
 	if(temp->context==DENEMO_NONE ||
-	   confirm("A context is set on this staff", "You will need to alter the staff->properties->context of this and the previous staff; Proceed?")) {
+	   confirm(_("A context is set on this staff"), _("You will need to alter the staff->properties->context of this and the previous staff; Proceed?"))) {
 	  take_snapshot();
 	  gui->si->currentstaff->data = gui->si->currentstaff->prev->data;
 	  gui->si->currentstaff->prev->data = temp;
@@ -486,10 +491,10 @@ swapstaffs (GtkAction *action, gpointer param)
 	}
       }
       else
-	warningdialog("Split off voices from this staff first");
+	warningdialog(_("Split off voices from this staff first"));
     }
   else
-    warningdialog("There is no previous staff to swap with");
+    warningdialog(_("There is no previous staff to swap with"));
   return FALSE;
 }
 
@@ -510,7 +515,7 @@ splitstaffs (GtkAction *action, gpointer param)
       if((thestaff->voicecontrol&DENEMO_PRIMARY) && (nextstaff->voicecontrol==DENEMO_SECONDARY))
 	nextstaff->voicecontrol=DENEMO_SECONDARY|DENEMO_PRIMARY;
       else
-	warningdialog("There is no voice below this one on this staff");
+	warningdialog(_("There is no voice below this one on this staff"));
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
       move_viewport_up (gui);
@@ -519,7 +524,7 @@ splitstaffs (GtkAction *action, gpointer param)
       return TRUE;
     }
   else
-    warningdialog("There is no voice below this one to split from");
+    warningdialog(_("There is no voice below this one to split from"));
   return FALSE;
 }
 
@@ -547,7 +552,7 @@ joinstaffs (GtkAction *action, gpointer param)
       return TRUE;
     }
   else
-    warningdialog("There is no staff above to move this staff into");
+    warningdialog(_("There is no staff above to move this staff into"));
   return FALSE;
 }
 
@@ -577,10 +582,11 @@ govoiceup (DenemoScriptParam *param, gboolean extend_selection)
     setcurrents (gui->si);
     show_lyrics();
     move_viewport_down (gui);
+    set_cursor_transition();
     return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-	warningmessage("This is the first voice");
+	warningmessage(_("This is the first voice"));
   return param->status = FALSE;
 }
 
@@ -610,15 +616,16 @@ gostaffup (DenemoScriptParam *param, gboolean extend_selection)
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
       if(extend_selection)
-	calcmarkboundaries (gui->si);
+				calcmarkboundaries (gui->si);
       show_lyrics();
       find_leftmost_allcontexts (si);
       update_drawing_cache();;
       move_viewport_up (gui);
+      set_cursor_transition();
       return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-	warningmessage("This is the first staff");
+				warningmessage(_("This is the first staff"));
   return param->status = FALSE;
 }
 
@@ -646,13 +653,15 @@ govoicedown (DenemoScriptParam *param, gboolean extend_selection)
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
       if(extend_selection)
-	calcmarkboundaries (gui->si);
+				calcmarkboundaries (gui->si);
       show_lyrics();
       move_viewport_down (gui);
+      set_cursor_transition();
       return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-      warningmessage("This is the last voice");
+      warningmessage(_("This is the last voice"));
+      
   return param->status = FALSE;
 }
 
@@ -713,16 +722,18 @@ gostaffdown (DenemoScriptParam *param, gboolean extend_selection)
       setcurrentprimarystaff (gui->si);
       setcurrents (gui->si);
       if(extend_selection)
-	calcmarkboundaries (gui->si);
+				calcmarkboundaries (gui->si);
       show_lyrics();
       find_leftmost_allcontexts (si);
       
       update_drawing_cache();;
       move_viewport_down (gui);
+      set_cursor_transition();
       return param->status = TRUE;
     } else
       if(param==&dummy)//is interactive
-      warningmessage("This is the last staff");
+      warningmessage(_("This is the last staff"));
+ 
   return param->status = FALSE;
 }
 
@@ -1548,29 +1559,6 @@ dnm_inserttuplet (DenemoGUI * gui, tuplet_type type)
   si->cursor_appending = FALSE;
 }
 
-/**
- * Insert grace note into the score
- * @param si pointer to the scoreinfo structure
- */
-void
-insertgrace (DenemoGUI * gui)
-{
-  DenemoScore *si = gui->si;
-  DenemoObject *mudela_obj_new;
-  insertion_point (si);
-
-
-  mudela_obj_new = newgracestart ();
-
-  object_insert (gui, mudela_obj_new);
-
-  object_insert (gui, newgraceend ());
-  si->cursor_x--;
-  si->currentobject =
-    g_list_nth ((objnode *) si->currentmeasure->data, si->cursor_x);
-  si->cursor_appending = FALSE;
-  // useless, never set false again ... si->is_grace_mode = TRUE;
-}
 
 /**
  * Change the duration of the current note/rest
@@ -2104,7 +2092,7 @@ dnm_deleteobject (DenemoScore * si)
   }
 #endif
   if(curmudelaobj->type==LILYDIRECTIVE && ((lilydirective *)curmudelaobj->object)->locked)
-    if(!confirm("This LilyPond insert is locked","Really delete it?"))
+    if(!confirm(_("This LilyPond insert is locked"),_("Really delete it?")))
       return;
   DenemoUndoData *undo;
 
@@ -2256,11 +2244,10 @@ toggle_tie (GtkAction *action, gpointer param)
       ((chord *) curmudelaobj->object)->notes)
     {
       store_for_undo_change (si, curmudelaobj);
-
-
       ((chord *) curmudelaobj->object)->is_tied ^= 1;
       gtk_widget_queue_draw (Denemo.scorearea);
     }
+   score_status(gui, TRUE);
 }
 
 
@@ -2276,7 +2263,7 @@ gotoend (gpointer param, gboolean extend_selection)
 {
   DenemoGUI *gui = Denemo.gui;
   if(extend_selection && !gui->si->markstaffnum) set_mark(gui);
-  gint dest = gui->si->currentmeasurenum = 
+  gui->si->currentmeasurenum = 
     g_list_length (((DenemoStaff *) gui->si->currentstaff->data)->measures);
   setcurrents (gui->si);
   if(extend_selection)
@@ -2286,9 +2273,8 @@ gotoend (gpointer param, gboolean extend_selection)
     cursorright(param);
   else
     movecursorright(param);
-update_drawing_cache();;//refresh cached values, eg current timesig
-  find_leftmost_allcontexts (gui->si);
-  update_hscrollbar (gui);
+	update_drawing_cache();;//refresh cached values, eg current timesig
+  find_leftmost_allcontexts (gui->si);//FIXME is this done in displayhelper?
   displayhelper (gui);
 }
 
@@ -2303,15 +2289,12 @@ gotohome (gpointer param, gboolean extend_selection)
   DenemoGUI *gui = Denemo.gui;
   if(extend_selection && !gui->si->markstaffnum) set_mark(gui);
   gui->si->currentmeasurenum = gui->si->leftmeasurenum = 1;
-  set_rightmeasurenum (gui->si);
+  displayhelper (gui);
   setcurrents (gui->si);
   if(extend_selection)
     calcmarkboundaries (gui->si);
   find_leftmost_allcontexts (gui->si);
-  update_hscrollbar (gui);
-  /*gtk_widget_draw (Denemo.scorearea, NULL);*/
   update_drawing_cache();;//refresh cached values, eg current timesig
-  gtk_widget_queue_draw (Denemo.scorearea);
 }
 
 
