@@ -70,11 +70,13 @@ find_context_of_object (DenemoScore *si, gint thetype)
 	return (DenemoObject *) curobj->data;
       else
 	curobj = curobj->prev;
-     if (!curobj)
+     if (curobj==NULL)
 	{			/* go back to preceding measure */
-	  curmeasure = curmeasure->prev;
-	  if(curmeasure)
+	  while(curmeasure = curmeasure->prev) 	{  
 	    curobj = lastobjnode (curmeasure);
+	    if(curobj)
+		break;
+	  }
 	}
     }
   return NULL;
@@ -157,7 +159,7 @@ find_leftmost_staffcontext (DenemoStaff * curstaffstruct, DenemoScore * si)
 
       si->maxkeywidth = MAX (si->maxkeywidth, 
 			     draw_key (NULL, 0, 0, curstaffstruct->leftmost_keysig->number,
-	      0, 0, FALSE));
+	      0, 0, FALSE, curstaffstruct->leftmost_keysig));
   if ((obj = find_measure_context (leftmeasure, TIMESIG)))
     {
       curstaffstruct->leftmost_timesig =
