@@ -22,7 +22,7 @@
 #include "pitchentry.h"
 #include "lyric.h"
 #include "midi.h"
-
+#include "displayanimation.h"
 
 #define EXCL_WIDTH 3
 #define EXCL_HEIGHT 13
@@ -45,7 +45,7 @@ void set_start_and_end_objects_for_draw(void) {
     Startobj =
       get_obj_for_end_time(Denemo.gui->si->smf, Denemo.gui->si->start_time - 0.001);
     Endobj =
-      get_obj_for_start_time(Denemo.gui->si->smf, Denemo.gui->si->end_time - 0.001);
+     Denemo.gui->si->end_time<0.0?NULL: get_obj_for_start_time(Denemo.gui->si->smf, Denemo.gui->si->end_time - 0.001);
   }
 }
 
@@ -188,11 +188,11 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
   DenemoObject *mudelaitem = (DenemoObject *) curobj->data;
 
   //g_print("draw obj %d %d\n", mudelaitem->x, y);
-  //this is the selection being given a green background
+  //this is the selection being given a colored background
   if(cr) if(itp->mark) {
     cairo_save(cr);
-    cairo_set_source_rgb( cr, 0.5, 1.0, 0.5 );
-    cairo_rectangle (cr, x+mudelaitem->x, y, 20, 80 );
+    cairo_set_source_rgba( cr, 0.8, 0.8, 0.4, 0.7);
+    cairo_rectangle (cr, x+mudelaitem->x, y, mudelaitem->minpixelsalloted, 80 );
     cairo_fill(cr);
     cairo_restore(cr);
   }
@@ -408,12 +408,6 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 			   x + mudelaitem->x, y, mudelaitem);
       itp->stem_directive = ((stemdirective *) mudelaitem->object)->type;
       break;
-    case GRACE_START:
-    case GRACE_END:
-      if(cr) draw_gracebracket (cr,
-			 x + mudelaitem->x, y, mudelaitem);
-      break;
-
     default:
       /* Nothing */
       break;
@@ -426,21 +420,21 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
     {				/* Draw the cursor */
       /* Determine if it needs to be red or not */
       if (si->cursor_appending || mudelaitem->type != CHORD)
-	si->cursoroffend =
-	  (mudelaitem->starttickofnextnote >= itp->tickspermeasure);
+				si->cursoroffend =
+						(mudelaitem->starttickofnextnote >= itp->tickspermeasure);
       else
-	si->cursoroffend =
-	  (mudelaitem->starttickofnextnote > itp->tickspermeasure);
+				si->cursoroffend =
+						(mudelaitem->starttickofnextnote > itp->tickspermeasure);
       if (si->cursor_appending)
-	{
-	  draw_cursor (cr, si, x + mudelaitem->x + extra, y, ((itp->curmeasure->next!=NULL) && (objnode *) itp->curmeasure->next->data)?-1:0 /*itp->last_gap */, gui->mode, si->cursorclef);
-	  memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
-	}
+				{
+					draw_cursor (cr, si, x + mudelaitem->x + extra, y, ((itp->curmeasure->next!=NULL) && (objnode *) itp->curmeasure->next->data)?-1:0 /*itp->last_gap */, 0, si->cursorclef);
+					memcpy (si->cursoraccs, itp->curaccs, SEVENGINTS);
+				}
       else
-	{
-	  draw_cursor (cr, si, x + mudelaitem->x, y, itp->last_gap, gui->mode,
+				{
+					draw_cursor (cr, si, x + mudelaitem->x, y, itp->last_gap, mudelaitem->type == CHORD?0:mudelaitem->minpixelsalloted,
 		       si->cursorclef);
-	}
+				}
     }
       /* End cursor drawing */
 
@@ -517,7 +511,7 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
   }
 
 
-  // draw the cursor and set the side effects up if this didn't happen when drawing the currentobject
+  // draw the cursor and set the side effects up if this didn't happen when drawing the currentobject because there isn't one - a blank measure
   if (!si->currentobject && (si->currentstaffnum == itp->staffnum && si->currentmeasurenum == itp->measurenum))
     {
       /* That is, the cursor's at the beginning of this blank measure */
@@ -602,8 +596,8 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
        (si->selection.laststaffmarked >= itp->staffnum) &&
        (si->selection.firstmeasuremarked <= itp->measurenum) &&
        (si->selection.lastmeasuremarked > itp->measurenum))      {
-	  cairo_set_source_rgb( cr, 0.5, 0.5, 1.0 );
-	  cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data), y, 20, STAFF_HEIGHT+1); 
+	  cairo_set_source_rgba( cr, 0.8, 0.8, 0.4, 0.7);
+	  cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data) - 10, y, 20, STAFF_HEIGHT+1); 
 	  
 	  cairo_fill(cr);
     } 
@@ -669,6 +663,8 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
   gboolean repeat = FALSE;
   DenemoScore *si = gui->si;
   gint x  = KEY_MARGIN, i;
+
+  
   //g_print("drawing staff %d at %d\n", itp->staffnum, y);
   gint nummeasures = g_list_length (thestaff->measures);
 
@@ -678,27 +674,25 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
   if(cr) {
 	  cairo_save(cr);
 	 
-  //Draw vertical lines to bind the staffs of the system together
-      if(curstaff->prev)
-	{
-	  DenemoStaff *prev = (DenemoStaff *)(curstaff->prev->data);	  
-	  cairo_set_source_rgb( cr, 0, 0, 0);
-	  cairo_rectangle (cr, LEFT_MARGIN, y - STAFF_HEIGHT - prev->space_below - thestaff->space_above, 2, 2*STAFF_HEIGHT + prev->space_below + thestaff->space_above);
-	  cairo_fill(cr);	 
-	}
-      if(curstaff->next)
-	{
-	  DenemoStaff *next = (DenemoStaff *)(curstaff->next->data);
-	  //cairo_save(cr);
-	  cairo_set_source_rgb( cr, 0, 0, 0);
-	  cairo_rectangle (cr, LEFT_MARGIN, y, 2, 2*STAFF_HEIGHT + next->space_above + thestaff->space_below);
-	  cairo_fill(cr);	 
-	}
+		//Draw vertical lines to bind the staffs of the system together
+		if(curstaff->prev) {
+			DenemoStaff *prev = (DenemoStaff *)(curstaff->prev->data);	  
+			cairo_set_source_rgb( cr, 0, 0, 0);
+			cairo_rectangle (cr, LEFT_MARGIN, y - STAFF_HEIGHT - prev->space_below - thestaff->space_above, 2, 2*STAFF_HEIGHT + prev->space_below + thestaff->space_above);
+			cairo_fill(cr);	 
+		}
+		if(curstaff->next) {
+			DenemoStaff *next = (DenemoStaff *)(curstaff->next->data);
+			//cairo_save(cr);
+			cairo_set_source_rgb( cr, 0, 0, 0);
+			cairo_rectangle (cr, LEFT_MARGIN, y, 2, 2*STAFF_HEIGHT + next->space_above + thestaff->space_below);
+			cairo_fill(cr);	 
+		}
 
-  if ((DenemoStaff *) si->currentstaff->data == thestaff)
-    cairo_set_source_rgb( cr, 0,0,0 );
-  else
-    cairo_set_source_rgb( cr, 0.3,0.3,0.3 );
+		if ((DenemoStaff *) si->currentstaff->data == thestaff)
+			cairo_set_source_rgb( cr, 0,0,0 );
+		else
+			cairo_set_source_rgb( cr, 0.3,0.3,0.3 );
   } //if cr
 
   if(!itp->line_end) {//not a continuation
@@ -712,7 +706,6 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
       draw_clef (cr, LEFT_MARGIN, y,
 	       itp->clef);
       cairo_restore(cr);
-
     }
 
     
@@ -728,19 +721,19 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
       thestaff->leftmost_timesig->time2;
     if(cr && !(thestaff->voicecontrol&DENEMO_SECONDARY)) {
       if(si->leftmeasurenum==1)  
-	draw_timesig (cr, x, y, itp->time1, itp->time2, thestaff->leftmost_timesig);
+				draw_timesig (cr, x, y, itp->time1, itp->time2, thestaff->leftmost_timesig);
       else {
-	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffGoBack));
-	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffGoBack));
-	cairo_save( cr );
-	gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(StaffGoBack), x,y );
-	cairo_rectangle( cr,x,y, width, height );
-	cairo_fill( cr );
-	cairo_restore( cr );
+				guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffGoBack));
+				guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffGoBack));
+				cairo_save( cr );
+				gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(StaffGoBack), x,y );
+				cairo_rectangle( cr,x,y, width, height );
+				cairo_fill( cr );
+				cairo_restore( cr );
       }
     }
     x += SPACE_FOR_TIME;
-  } else {
+  } else { // a continuation line
     if(cr && !(thestaff->voicecontrol&DENEMO_SECONDARY)) draw_clef (cr, LEFT_MARGIN, y, itp->clef);
     if(cr && !(thestaff->voicecontrol&DENEMO_SECONDARY)) draw_key (cr, x, y,
 		     itp->key, 0, itp->clef->type, TRUE, thestaff->leftmost_keysig);
@@ -756,22 +749,29 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
   itp->tickspermeasure = WHOLE_NUMTICKS * itp->time1 / itp->time2;
 
   if(cr) {
-  /* Draw staff name on first system */
-  if(!itp->line_end) {
-    gint staffname_offset = (thestaff->voicecontrol&DENEMO_PRIMARY) ? 24 :12;
-    drawnormaltext_cr( cr, thestaff->denemo_name->str, 0/*KEY_MARGIN*/, y - staffname_offset+10 );
-  } else {
-  cairo_save(cr);
-  gint staffname_offset = (thestaff->voicecontrol&DENEMO_PRIMARY) ? 24 : 12;
-  cairo_translate(cr, 2, (y - staffname_offset+30) );
-  cairo_rotate( cr,- M_PI/5.0 );
-  drawnormaltext_cr( cr, thestaff->denemo_name->str, 0,0 );
-  cairo_restore(cr);
-  }
-
-  // cairo_save(cr);
+		/* Draw staff name on first system */
+		if(!itp->line_end) {
+			gint staffname_offset = (thestaff->voicecontrol&DENEMO_PRIMARY) ? 24 :12;
+			drawnormaltext_cr( cr, thestaff->denemo_name->str, 0/*KEY_MARGIN*/, y - staffname_offset+10 );
+		} else {
+			cairo_save(cr);
+			gint staffname_offset = (thestaff->voicecontrol&DENEMO_PRIMARY) ? 24 : 12;
+			cairo_translate(cr, 2, (y - staffname_offset+30) );
+			cairo_rotate( cr,- M_PI/5.0 );
+			drawnormaltext_cr( cr, thestaff->denemo_name->str, 0,0 );
+			cairo_restore(cr);
+		}
   }//if cr
 
+
+
+	x += transition_offset();
+
+
+
+
+
+
   if((gui->si->smf) && (itp->startobj==NULL) && (itp->startposition<=0) && (si->leftmeasurenum==1))
     itp->startposition = x;
 
@@ -801,12 +801,12 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 
   if(!*itp->scale)
     *itp->scale=100;
- if(cr) {
+	if(cr) {
    cairo_scale(cr, 100.0/(*itp->scale),1.0);
 	    //cairo_scale(cr,(*itp->scale)/100.0,1.0);
- }
+	}
 
- gint scale_before=*itp->scale;
+	gint scale_before=*itp->scale;
   itp->line_end = FALSE;
   cairo_t *saved_cr = NULL;
   if(itp->source_displayed) {//We have displayed source material below the last staff, so do not draw anymore staff music. We cannot simply skip the drawing routines however, because they determine the rightmost bar for mouse positioning, so we save and restore it.
@@ -814,14 +814,16 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
     cr = NULL;
   }
     
-  while ( (!itp->line_end) 
-	 && itp->measurenum <= nummeasures)
-    {
-      if( x + GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE >
-	  (int)(get_widget_width(Denemo.scorearea)/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME)))
-	  itp->line_end=TRUE;
+  while ( (!itp->line_end)  && itp->measurenum <= nummeasures) {
+
+     if( x + GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE >
+					(int)(get_widget_width(Denemo.scorearea)/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME)))
+				itp->line_end=TRUE;
 
 	  itp->last_gap = 0;
+
+	  if(itp->measurenum == si->currentmeasurenum)
+			x += measure_transition_offset(si->currentstaffnum==itp->staffnum);
 	  draw_measure (cr, itp->curmeasure, x, y, gui, itp);
 	  if(cr && (Denemo.gui->view!=DENEMO_PAGE_VIEW) && (si->sources||thestaff->sources) && (si->currentstaffnum == itp->staffnum)) {
 	    GdkPixbuf* source = (GdkPixbuf*)g_list_nth_data(si->sources?gui->si->sources:thestaff->sources, itp->measurenum-1);
@@ -833,10 +835,10 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 		      gint xpos = x;
 		      cairo_save( cr );
 		      if(scale<1.0) {//too large to fit under the measure
-			cairo_translate( cr, x*(1-scale), ypos*(1-scale));
-			cairo_scale(cr, scale, scale);
+						cairo_translate( cr, x*(1-scale), ypos*(1-scale));
+						cairo_scale(cr, scale, scale);
 		      } else
-		      xpos = x - (width - GPOINTER_TO_INT (itp->mwidthiterator->data))/2;//narrow, center it
+						xpos = x - (width - GPOINTER_TO_INT (itp->mwidthiterator->data))/2;//narrow, center it
 		      gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(source), xpos,ypos );
 		      cairo_rectangle( cr,xpos,ypos, width, height );
 		      cairo_fill( cr );
@@ -844,31 +846,38 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 		      itp->source_displayed = TRUE;
 	    }
 	  }
-	x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
 
-	if((Denemo.gui->view!=DENEMO_PAGE_VIEW && itp->line_end && itp->measurenum > si->rightmeasurenum)
-	  ||(Denemo.gui->view==DENEMO_PAGE_VIEW && itp->line_end && itp->curmeasure->next))
-		*itp->scale = (int)(100*x/(get_widget_width(Denemo.scorearea)/gui->si->zoom));
-	else
-	  *itp->scale = 100;
+		x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
 
-    itp->curmeasure = itp->curmeasure->next;
-    itp->mwidthiterator = itp->mwidthiterator->next;
 
-    itp->measurenum++;
-    //g_print("line_end is %d, while itp->measurenum=%d and si->rightmeasurenum=%d\n",  itp->line_end, itp->measurenum, si->rightmeasurenum);
-    if(!itp->line_end) {
-	if(-itp->highy>itp->in_highy && -itp->highy<MAXEXTRASPACE) {
-	  //g_print("With %d to change %d\n", -itp->highy, itp->in_highy);
-	  thestaff->space_above = -itp->highy;
-	  repeat = TRUE;
-	}
-	if(itp->lowy>itp->in_lowy && itp->lowy<MAXEXTRASPACE){
-	  thestaff->space_below = itp->lowy;
-	  repeat = TRUE;
-	}
-      }			      
-    } // end of loop drawing each measure
+		if(
+#if 0
+/* do not scale the non page views as it perturbs the display animation and anyway does not add anything */
+		(Denemo.gui->view!=DENEMO_PAGE_VIEW && itp->line_end && itp->measurenum > si->rightmeasurenum)
+			||
+#endif			
+			(Denemo.gui->view==DENEMO_PAGE_VIEW && itp->line_end && itp->curmeasure->next))
+				*itp->scale = (int)(100*x/(get_widget_width(Denemo.scorearea)/gui->si->zoom));
+		else
+			*itp->scale = 100;
+
+		itp->curmeasure = itp->curmeasure->next;
+		itp->mwidthiterator = itp->mwidthiterator->next;
+
+		itp->measurenum++;
+			//g_print("line_end is %d, while itp->measurenum=%d and si->rightmeasurenum=%d\n",  itp->line_end, itp->measurenum, si->rightmeasurenum);
+		if(!itp->line_end) {
+			if(-itp->highy>itp->in_highy && -itp->highy<MAXEXTRASPACE) {
+				//g_print("With %d to change %d\n", -itp->highy, itp->in_highy);
+				thestaff->space_above = -itp->highy;
+				repeat = TRUE;
+			}
+			if(itp->lowy>itp->in_lowy && itp->lowy<MAXEXTRASPACE){
+				thestaff->space_below = itp->lowy;
+				repeat = TRUE;
+			}
+		}			      
+  } // end of loop drawing each measure
   if(scale_before!=*itp->scale)
     repeat = TRUE;/* the first system is already drawn, so it is too late to discover that we needed to scale it */
   *itp->right = itp->measurenum-1;
@@ -894,7 +903,7 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 	     guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffGoForward));
 	     guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffGoForward));
 	     cairo_save( cr );
-             gint xx = get_widget_width(Denemo.scorearea)/gui->si->zoom -width;
+       gint xx = get_widget_width(Denemo.scorearea)/gui->si->zoom -width;
 	     gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(StaffGoForward),xx,y );
 	     cairo_rectangle( cr,xx,y, width, height );
 	     cairo_fill( cr );
@@ -928,9 +937,11 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
     }
   if(saved_cr)
     cr = saved_cr;
-  
+ 
   return repeat;
 }
+
+
 static void
 print_system_separator (cairo_t *cr, gdouble position){
   //g_print("At %f for %d\n", position, Denemo.scorearea->allocation.height);
@@ -952,20 +963,27 @@ static void draw_playback_marker(cairo_t *cr, gint color, gint pos, gint yy, gin
   cairo_set_line_width( cr, 4.0 );
   switch(color) {
   case BLACK:
-    cairo_set_source_rgb( cr, 0.0, 0.0, 0.0 );
+    cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 0.5);
     break;
   case GREEN:
-    cairo_set_source_rgb( cr, 0.0, 1.0, 0.0 );
+    cairo_set_source_rgba(cr, 0.0, 1.0, 0.0, 0.5);
     break;
   case RED:
-    cairo_set_source_rgb( cr, 1.0, 0.0, 0.0 );
+    cairo_set_source_rgba(cr, 1.0, 0.0, 0.0, 0.5);
+    break;
+  }
+  cairo_move_to(cr, pos, yy-STAFF_HEIGHT);
+  cairo_line_to(cr, pos, yy-STAFF_HEIGHT+line_height);
+  cairo_stroke(cr);
+  switch(color) {
+    case GREEN:
+    drawlargetext_cr(cr, _("Playback Start"), pos - 100, yy);
+    break;
+  case RED:
+    drawlargetext_cr(cr, _("Playback End"), pos - 100, yy);
     break;
   }
-  cairo_move_to( cr, pos, yy-STAFF_HEIGHT );
-  cairo_line_to( cr, pos, yy-STAFF_HEIGHT+line_height);
-  cairo_stroke( cr );
   cairo_restore(cr);
-
 }
 
 static void draw_playback_markers(cairo_t *cr, struct infotopass *itp, gint yy, gint line_height) {
@@ -1029,7 +1047,7 @@ draw_score (cairo_t *cr)
   itp.startobj =  itp.endobj = NULL;
   itp.tupletstart = itp.tuplety = 0;
   y = 0;
-
+	
   if(gui->si->smf) {
     itp.startobj = Startobj;
     // g_print("start %p\n", itp.startobj);
@@ -1037,7 +1055,7 @@ draw_score (cairo_t *cr)
     itp.endobj = Endobj;
     //g_print("Start time %p %f end time %p %f\n", itp.startobj, si->start_time, itp.endobj, si->end_time);
   }
-
+if(cr) cairo_translate(cr, movement_transition_offset(), 0);
   /* The colour for staff lines and such is black. */
   if (cr) cairo_set_source_rgb( cr, 0, 0, 0 );
 
@@ -1054,8 +1072,10 @@ draw_score (cairo_t *cr)
     DenemoStaff *staff = (DenemoStaff *) curstaff->data;
     itp.verse = staff->currentverse?staff->currentverse->data:NULL;
     GdkPixbuf *StaffDirectivesPixbuf = (si->currentstaffnum==itp.staffnum)?StaffPixbuf:StaffPixbufSmall;
-      
-
+   if (si->currentstaffnum==itp.staffnum)
+			y += staff_transition_offset();
+			
+		
     if (curstaff && staff->voicecontrol&DENEMO_PRIMARY)
       y += staff->space_above;
 
