@@ -24,17 +24,17 @@ draw_stem_directive (cairo_t *cr,
   switch (((stemdirective *) theobj->object)->type)
     {
     case DENEMO_STEMUP:
-      text = _("stem\nup");
+      text = _("⬆stem");
       break;
     case DENEMO_STEMBOTH:
-      text = _("auto\nstems");
+      text = _("⬆⬇stems");
       break;
     case DENEMO_STEMDOWN:
-      text = _("stem\ndown");
+      text = _("⬆stems");
       break;
     }
   if(((stemdirective *) theobj->object)->directives)
-    draw_for_directives(cr, ((stemdirective *) theobj->object)->directives, xx, y-4);
+    draw_for_directives(cr, ((stemdirective *) theobj->object)->directives, xx, y-4, TRUE);
   else
     drawnormaltext_cr( cr, text, xx, y - 4);
 }
