@@ -4,7 +4,7 @@
  * Functions for exporting a Standard Midi file
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
- * (C) 2001, 2002 Per Andersson, 2009 Richard Shann
+ * (C) 2001, 2002 Per Andersson, 2009, 2010, 2011, 2012 Richard Shann
  * 
  * License: this file may be used under the FSF GPL version 3 or later
  */
@@ -60,7 +60,7 @@
 #include "exportmidi.h"
 #include "smf.h"
 #include "instrumentname.h"
-#include "device_manager.h"
+#include "audiointerface.h"
 
 /* 
  * only for developers
@@ -1201,11 +1201,13 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 
       /* tempo */
       gint cur_tempo = si->tempo;
-      event = midi_tempo (cur_tempo);
-      smf_track_add_event_delta_pulses(track, event, 0);
-      
+
+      if(tracknumber==1) {//Do not set the tempo for later tracks as there may be tempo directives at the start of the first measure which libsmf will muddle up with any done here
+	event = midi_tempo (cur_tempo);
+	smf_track_add_event_delta_pulses(track, event, 0);
+      }
       /* Midi Client/Port */
-      track->user_pointer = (DevicePort *) device_manager_get_DevicePort(curstaffstruct->device_port->str); 
+//      track->user_pointer = (DevicePort *) device_manager_get_DevicePort(curstaffstruct->device_port->str); 
 
       /* The midi instrument */
       if(curstaffstruct->midi_instrument && curstaffstruct->midi_instrument->len) {
@@ -1355,6 +1357,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 	 * 	that seems relevant to us
 	 *******************************************/
 	      int tmpstaccato = 0, tmpstaccatissimo = 0;
+	      gboolean skip_midi = FALSE;
 	      GList *tmp;
 
 	      switch (curobj->type)
@@ -1386,7 +1389,10 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			  switch(midi_override) 
 			    {
 			    case DENEMO_OVERRIDE_VOLUME:
+			      if(midi_val)
 				change_volume(&cur_volume, midi_val, midi_interpretation, midi_action);
+				else
+				  skip_midi = TRUE;
 			      break;
 			    case DENEMO_OVERRIDE_TRANSPOSITION:
 				cur_transposition = midi_val;
@@ -1406,9 +1412,10 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			      //etc			      
 			    default:
 			      if(!(midi_override&DENEMO_OVERRIDE_HIDDEN))
-			      if(buffer) 
+			      if(buffer) {
 				if(NULL==put_event(buffer, numbytes, &curobj->midi_events, track))
 				  g_warning("Invalid midi bytes in chord directive\n");
+			      } 
 			      break;
 			    }
 			}//for each directive attached to the chord
@@ -1491,6 +1498,12 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		  if (!chordval.notes) {
 		    //MUST GIVE OFF TIME FOR RESTS HERE
 		    curobj->latest_time = curobj->earliest_time + duration*60.0/(cur_tempo*MIDI_RESOLUTION);
+		    //g_print("Adding Dummy event for rest %d %d %d\n", duration, ticks_read, ticks_written); 
+		    event = midi_meta_text (1/* comment*/, "rest");
+		    smf_track_add_event_delta_pulses(track, event, duration);
+		    curobj->midi_events = g_list_append(curobj->midi_events, event);
+		    ticks_written += duration;
+		    event->user_pointer = curobj;
 		    //g_print("rest of %f seconds at %f\n", duration/(double)MIDI_RESOLUTION, curobj->latest_time);
 		  }
 
@@ -1528,33 +1541,39 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 		      for (curtone = chordval.notes; curtone;
 			   curtone = curtone->next)
 			{
-			  if (chordval.has_dynamic){
+			  note *thenote = (note *)curtone->data;
+			  GList *g;
+			  
+#ifdef NOTE_MIDI_OVERRIDES_IMPLEMENTED
+			  for(g = thenote->directives; g ; g=g->next) {
+			    DenemoDirective *directive = g->data;
+			    gint midi_override = directive_get_midi_override(directive);
+			    if(midi_override)
+			      skip_midi = TRUE;//TODO if it *is* overriden take action e.g. increase volume etc. For now we just drop it
+			  }
+#endif
+			  if(!skip_midi) {
+			    if (chordval.has_dynamic){
 			      g_debug("\nThis chord has a dynamic marking attatched\n");
 			      GList *dynamic = g_list_first(chordval.dynamics);	
 			      cur_volume =
 		              string_to_vol (((GString *) dynamic->data)->str,
 				   cur_volume);
-			  }
-
-			  mid_c_offset =
-			    ((note *) curtone->data)->mid_c_offset;
-			  enshift = ((note *) curtone->data)->enshift;
-			  //printf("mid_c_offset = %i\n",mid_c_offset);
-			  //printf("enshift = %i\n",enshift);
-			  notenumber =
-			    dia_to_midinote (mid_c_offset) + enshift;
-			  //printf ("transposition = %i\n",
-			  //	  curstaffstruct->transposition);
-			  notenumber += cur_transposition;
-			  //printf ("notenumber = %i\n", notenumber);
-			  if(notenumber>127) {
-			    g_warning("Note out of range\n", notenumber = 60);
-			  }
-			  slur_note (note_status,
+			    }
+			    mid_c_offset = thenote->mid_c_offset;
+			    enshift = thenote->enshift;			  
+			    notenumber = dia_to_midinote (mid_c_offset) + enshift;			  
+			    notenumber += cur_transposition;
+			  
+			    if(notenumber>127) {
+			      g_warning("Note out of range\n", notenumber = 60);
+			    }
+			    slur_note (note_status,
 				     slur_status,
 				     notenumber,
 				     tmpstaccato,
 				     tmpstaccatissimo, chordval.is_tied);
+			  }
 			  
 			}
 		      /* End chord read loop */
@@ -1599,6 +1618,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			      // FIXME the function compress is returning large values.
 			      event = smf_event_new_from_bytes (MIDI_NOTE_ON | midi_channel, n, (mute_volume ? 0:cur_volume/*FIXME as above, mix*/));
 			      smf_track_add_event_delta_pulses(track, event, mididelta);
+			      //g_print("Note  on for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
 			      //g_print("Note on %x %x %x\n", MIDI_NOTE_ON | midi_channel, n, (mute_volume ? 0:cur_volume/*FIXME as above, mix*/));
 			      //g_print("event on %f\n", event->time_seconds);
 			      event->user_pointer = curobj;
@@ -1617,6 +1637,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			      event = smf_event_new_from_bytes ( MIDI_NOTE_OFF | midi_channel, n, 0);
 			      //g_print("{%d}", event->event_number);
 			      smf_track_add_event_delta_pulses(track, event, mididelta);
+			      //g_print("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
 			      event->user_pointer = curobj;
 			      curobj->midi_events = g_list_append(curobj->midi_events, event);
 			      
@@ -1668,6 +1689,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			      event = smf_event_new_from_bytes ( MIDI_NOTE_OFF | midi_channel, n, 60);
 			      //g_print("smf length before %d %f mididelta %d",smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
 			      smf_track_add_event_delta_pulses(track, event, mididelta);
+			      //g_print("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
 			      //g_print("smf length after %d %f mididelta %d", smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
 			      event->user_pointer = curobj;
 			      curobj->midi_events = g_list_append(curobj->midi_events, event);
@@ -1839,9 +1861,11 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 			change_tempo(&cur_tempo, midi_val, midi_interpretation, midi_action);
 			if(cur_tempo) {
 			  event = midi_tempo (cur_tempo);
-			  smf_track_add_event_delta_pulses(track, event, 0);
-			} else
-			  g_warning("Tempo change to 0 bpm is illegal");
+			  smf_track_add_event_delta_pulses(track, event, 0);//!!!!!!!!!! if rests precede this it is not at the right time...
+			} else {
+			  g_warning("Tempo change to 0 bpm is illegal - re-setting.");
+			  cur_tempo = 120;
+			}
 			break;
 		      case DENEMO_OVERRIDE_DURATION:
 			theduration = midi_interpretation;
@@ -1949,6 +1973,9 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
   }
   /* we are done */
   {gboolean midi_track = FALSE;
+  
+  
+g_static_mutex_lock (&smfmutex);
     if(Denemo.gui->si->recorded_midi_track) {
       if(si->smf && (((smf_track_t*)Denemo.gui->si->recorded_midi_track)->smf==si->smf)) {
 	smf_track_remove_from_smf(Denemo.gui->si->recorded_midi_track);
@@ -1959,11 +1986,11 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
     si->smf = smf;
     if(midi_track)
       smf_add_track(smf, Denemo.gui->si->recorded_midi_track);
-  }
+
   
-  si->smfsync = si->changecount;
-
-
+    si->smfsync = si->changecount;
+g_static_mutex_unlock (&smfmutex);
+  }
 
   if(start || end)
     return exportmidi(NULL, si, 0, 0);// recurse if we have not generated all the MIDI for si
