@@ -364,6 +364,7 @@ newDirectivesElem(xmlNodePtr objElem, xmlNsPtr ns, GList *g, gchar *type) {
     DO_DIREC(postfix);
     DO_DIREC(display);
     DO_DIREC(midibytes);
+    DO_DIREC(grob);
     DO_DIREC(graphic_name);
     
     DO_INTDIREC(minpixels);
@@ -683,9 +684,10 @@ else
  * Export the given score (from measure start to measure end) as a "native"
  * Denemo XML file to the given file.
  */
-void
+gint 
 exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 {
+	gint ret=0;
   GString *filename = g_string_new (thefilename);
   xmlDocPtr doc;
   xmlNodePtr scoreElem, mvmntElem, stavesElem, voicesElem, voiceElem;
@@ -978,14 +980,12 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		  xmlSetProp (objElem, (xmlChar *) "id",
 			      (xmlChar *) chordXMLID);
 
-		  if (thechord->is_grace)
+		  if (thechord->is_grace & GRACED_NOTE)
 		    xmlSetProp (objElem, (xmlChar *) "grace", (xmlChar *)
 				"true");
-		  // else
-		  //  xmlSetProp (objElem, (xmlChar *) "grace",
-		  //		(xmlChar *) "true");
-
-
+		 else if (thechord->is_grace & ACCIACCATURA)
+		    xmlSetProp (objElem, (xmlChar *) "grace", (xmlChar *)
+				"acciaccatura");
 
 		  /* Output the duration. */
 
@@ -1405,6 +1405,7 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
 		    SETSTRING_PROP (tag);
 		    SETSTRING_PROP (display);
 		    SETSTRING_PROP (midibytes);
+		    SETSTRING_PROP (grob);
 		    SETSTRING_PROP (graphic_name);
 		    SETSTRING_PROP (prefix);//postfix done above, for backward compatibility
 #undef SETSTRING_PROP
@@ -1449,13 +1450,12 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
     }				/* end for each voice in score */
   }// for each movement
   /* Save the file. */
-#if 0
-  if (xmlSaveFile (filename->str, doc) < 0)
+
+  if (xmlSaveFormatFile (filename->str, doc, 1) < 0) {
     g_warning ("Could not save file %s", filename->str);
-#else
-  if (xmlSaveFormatFile (filename->str, doc, 1) < 0)
-    g_warning ("Could not save file %s", filename->str);
-#endif
+    ret = -1;
+	} 
+
   /* Clean up all the memory we've allocated. */
 
   xmlFreeDoc (doc);
@@ -1464,4 +1464,5 @@ exportXML (gchar * thefilename, DenemoGUI *gui, gint start, gint end)
   sNextXMLID = 0;
 
   g_string_free (filename, TRUE);
+  return ret;
   }
