@@ -36,8 +36,9 @@
 #include <string.h>
 #include <sys/stat.h>		/* check existance and type of files */
 #include <dirent.h>		/* filter and sort filenames */
-
-
+#include "source.h"
+#include "sourceaudio.h"
+#include "pitchentry.h"
 
 static gint
 file_open (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *filename);
@@ -86,9 +87,7 @@ static struct FileFormatData supported_file_formats[] = {/* WARNING this array h
 static gchar* supported_denemo_file_extension[] = {
   "*.denemo", "*.DENEMO" 
 };
-static gchar *supported_dnm_file_extension[] = {
-  "*.dnm", "*.DNM" 
-};
+
 static gchar *supported_lilypond_file_extension[] = {
   "*.ly", "*.LY" 
 };
@@ -138,16 +137,16 @@ confirm_save (DenemoGUI *gui, gchar *primary, gchar *secondary)
 				   GTK_MESSAGE_QUESTION,
 				   GTK_BUTTONS_NONE,
 				   "%s", primary);
-  GtkWidget *d_save = gtk_dialog_add_button( (GtkDialog*)dialog, 
-                                          "Close without Saving",
+  (void) gtk_dialog_add_button( (GtkDialog*)dialog, 
+                                          _("Close without Saving"),
                                           GTK_RESPONSE_NO);
 	
-  GtkWidget *cancel = gtk_dialog_add_button( (GtkDialog*)dialog, 
-                                          GTK_STOCK_CANCEL,
+  (void) gtk_dialog_add_button( (GtkDialog*)dialog, 
+                                          _(GTK_STOCK_CANCEL),
                                           GTK_RESPONSE_CANCEL);
 	
-  GtkWidget *save = gtk_dialog_add_button( (GtkDialog*)dialog, 
-                                          GTK_STOCK_SAVE_AS,
+  (void)gtk_dialog_add_button( (GtkDialog*)dialog, 
+                                          _(GTK_STOCK_SAVE_AS),
                                           GTK_RESPONSE_YES);
 	
   gtk_dialog_set_default_response( (GtkDialog*)dialog, GTK_RESPONSE_YES);
@@ -187,7 +186,7 @@ confirm_save (DenemoGUI *gui, gchar *primary, gchar *secondary)
 gboolean
 confirmbox (DenemoGUI * gui) {
   gboolean ret;
-  gchar *primary = g_strdup_printf(_("The score %s has unsaved changes"), gui->filename->len?gui->filename->str:"(Untitled)");
+  gchar *primary = g_strdup_printf(_("The score %s has unsaved changes"), gui->filename->len?gui->filename->str:_("(Untitled)"));
   ret = confirm_save (gui, primary,  _("Save changes?"));
   g_free(primary);
   return ret;
@@ -221,7 +220,7 @@ openrecent (GtkWidget * widget, gchar *filename)
       // deletescore(NULL, gui);
       if(open_for_real (filename, gui, FALSE, FALSE))
 	{
-	  gchar *warning = g_strdup_printf("Load of recently used file %s failed", filename);
+	  gchar *warning = g_strdup_printf(_("Load of recently used file %s failed"), filename);
 	  warningdialog(warning);
 	  g_free(warning);
 	}
@@ -308,8 +307,7 @@ lyinput(gchar *filename, DenemoGUI *gui) {
  * @return 0 for success non zero for failure
  */
 gint
-open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, ImportType type)
-{
+open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, ImportType type) {
   g_signal_handlers_block_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
   gint result;
   gboolean xml = FALSE;
@@ -329,56 +327,56 @@ open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, Impor
         result = importMidi (filename, gui);
       else if(EXISTS(".pdf") || EXISTS(".PDF")) {// a .pdf file for transcribing from, does not affect the current score.
         g_signal_handlers_unblock_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
-        return !open_source (filename, 0, 0);
+        return !open_source (filename, 0, 0, 0);
       }
 #undef EXISTS
     }
   //printf("\nResult == %d type == %d template == %d xml == %d\n",result,type,template,(int)xml);
-  if (result == 0)
-    {
-      if(!template) 
-	{// not a template
-	  update_file_selection_path (filename);
-	  if(type==REPLACE_SCORE)
-	    {
-	      if (xml)
-	        set_gui_filename (gui, filename);
-	      else 
-	        {
-		  gchar *sname = strip_path_and_extension (filename);
-		  set_gui_tabname (gui, sname);
-		  g_free(sname);
-	        }
-	    }
-
-	  if(type==ADD_STAFFS || type==ADD_MOVEMENTS)
-	    score_status(gui, TRUE);
-        } else 
-	  g_string_assign (gui->filename, "");
+  if (result == 0) {
+      if(!template) {// not a template
+					update_file_selection_path (filename);
+					if(type==REPLACE_SCORE) {
+						if (xml)
+							set_gui_filename (gui, filename);
+						else 
+							{
+								gchar *sname = strip_path_and_extension (filename);
+								set_gui_tabname (gui, sname);
+								g_free(sname);
+							}
+					}
+					if(type==ADD_STAFFS || type==ADD_MOVEMENTS)
+						score_status(gui, TRUE);						
+			} else {
+				g_string_assign (gui->filename, "");
+			}
       if(Denemo.printarea) 
-	g_object_set_data(G_OBJECT(Denemo.printarea), "printviewupdate", (gpointer)G_MAXUINT);
+				g_object_set_data(G_OBJECT(Denemo.printarea), "printviewupdate", (gpointer)G_MAXUINT);
       if(!xml)
-	updatescoreinfo (gui);
-      set_rightmeasurenum (gui->si);
-      select_lyrics();
-      set_bottom_staff (gui);
-      update_hscrollbar (gui);
-      update_vscrollbar (gui);
-      gtk_widget_queue_draw (Denemo.scorearea);
-      g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
-      g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
-      force_lily_refresh(gui);
-    } else /*file load failed - gui may not be valid */
+				updatescoreinfo (gui);
+			else {
+				if(getNumCharsSchemeText()) {
+						gui->has_script = TRUE;
+						executeScript();
+				}
+			}
+			set_rightmeasurenum (gui->si);
+			select_lyrics();
+			set_bottom_staff (gui);
+			update_hscrollbar (gui);
+			update_vscrollbar (gui);
+			gtk_widget_queue_draw (Denemo.scorearea);
+			g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
+			g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+			force_lily_refresh(gui);
+  } else /*file load failed - gui may not be valid */ {
     deletescore(NULL, gui);
-      
+  }   
   g_signal_handlers_unblock_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
   gui->si->undo_guard=1;
-
-
   denemo_scheme_init();//to re-instate any user defined directives for whole score
   if(!(type==ADD_STAFFS || type==ADD_MOVEMENTS))
 	    score_status(gui, FALSE);
-
   rewind_audio();
   gui->si->undo_guard=Denemo.prefs.disable_undo;//user pref to (dis)allow undo information to be collected
   return result;
@@ -405,13 +403,13 @@ strip_filename_ext (const gchar * file_name, gint format_id)
 {
     gchar *ext = strrchr(file_name, '.');
     if (ext == NULL)
-      return file_name;
+      return g_strdup(file_name);
     gint i;
     GString *file_name_stripped = g_string_new ("");
     gint filename_size = strlen(file_name);
     gint ext_size = strlen(FORMAT_EXTENSION (format_id));
     if (strlen(ext) != ext_size)
-      return file_name;
+      return g_strdup(file_name);
     gint stripped_filename_size = filename_size - ext_size;
     for (i=0;i < stripped_filename_size;i++){
       g_string_append_c(file_name_stripped, file_name[i]);
@@ -424,69 +422,72 @@ strip_filename_ext (const gchar * file_name, gint format_id)
    if filename is NULL)
    If there is a scheme script, offers to save that with the file.
  */
-static void 
+static gint 
 save_in_format(gint format_id, DenemoGUI * gui, gchar *filename) {
+	gint ret = 0;
   gchar *file = filename? filename:gui->filename->str;
   switch (format_id)
     {
     case DENEMO_FORMAT:
     case DNM_FORMAT:
       {
-	/* HERE examine Denemo.Script and 
+			/* HERE examine Denemo.Script and 
          * if present ask it it should be 
          * saved with the file, if not 
          * delete the script.
-	 */
+			*/
 	    
-	if(getNumCharsSchemeText())
-	  if(!confirm("You have a Script defined", 
+			if((!gui->has_script) && getNumCharsSchemeText())
+				if(!confirm("You have a Script defined", 
 		      "Use this script every time this file is opened?")) 
-	  {
-	    deleteSchemeText();
-	  }										 
-	exportXML (file, gui, 0, 0);
-	break;
+				{
+				deleteSchemeText();
+				}										 
+				ret = exportXML (file, gui, 0, 0);
+				break;
       };
     case MUDELA_FORMAT:
       {
-	gui->si->markstaffnum = 0;
-	exportlilypond (file, gui, TRUE);
-	break;
+				gui->si->markstaffnum = 0;
+				exportlilypond (file, gui, TRUE);
+				break;
       };
     case PDF_FORMAT:
       {
-	gui->si->markstaffnum = 0;
+				gui->si->markstaffnum = 0;
         export_pdf (file, gui);
         break;
       };
     case PNG_FORMAT:
       {
-	gui->si->markstaffnum = 0;
-	export_png (file, (GChildWatchFunc)printpng_finished, gui);
+				gui->si->markstaffnum = 0;
+				export_png (file, (GChildWatchFunc)printpng_finished, gui);
         break;
       };
     case ABC_FORMAT:
       {
-	exportabc (file, gui, 0, 0);
-	break;
+				exportabc (file, gui, 0, 0);
+				break;
       };
     case MIDI_FORMAT:
       {
-	exportmidi (file, gui->si, 0, 0);
-	break;
+				exportmidi (file, gui->si, 0, 0);
+				break;
       };
     default:
       break;
     };
+ return ret;
 }
 
 /**
  * File save called by fileselsave callback
  * param file_name is full path to file possibly with extension
  */
-static void
+static gint
 filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSaveType template)
 {
+	gint ret = 0;
   g_assert (gui != NULL);
   g_assert (file_name != NULL);
   g_assert (format_id >= 0 && format_id <
@@ -505,9 +506,9 @@ filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSa
   if (basename[0] != '.') // avoids empty filename
     {
       if (FORMAT_ASYNC(format_id))
-        save_in_format(format_id, gui, strip_filename_ext(file_name, format_id));
+        ret = save_in_format(format_id, gui, strip_filename_ext(file_name, format_id));//FIXME strip_filename is not freed
       else
-        save_in_format(format_id, gui, file);
+        ret = save_in_format(format_id, gui, file);
  
       /*export parts as lilypond files*/
       if(Denemo.prefs.saveparts)
@@ -516,6 +517,7 @@ filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSa
     }
   g_free(basename);
   g_free(file);
+  return ret;
 }
 
 /* set local_template_path up */
@@ -727,7 +729,6 @@ set_current_folder(GtkWidget *file_selection, DenemoGUI *gui, DenemoSaveType tem
 gchar *
 file_dialog(gchar *message, gboolean type, gchar *location){
   GtkWidget *file_selection;
-  GtkFileFilter *filter;
   gchar *filename;
   file_selection = gtk_file_chooser_dialog_new (message,
 						GTK_WINDOW (Denemo.window),
@@ -844,8 +845,7 @@ static gint
 file_open (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *filename)
 {
   FILE_OPEN_DIALOG("Open", denemo, DENEMO_FORMAT)
-  if(getNumCharsSchemeText())
-	  executeScript(); 
+
 }
 
 gint open_source_file(void){
@@ -898,9 +898,12 @@ file_saveaswrapper (GtkAction * action, DenemoScriptParam *param)
   GET_1PARAM(action, param, filename);
   DenemoGUI *gui = Denemo.gui;
   if(filename==NULL) {
-    file_saveas (gui, FALSE);
-  } else {
-      filesel_save (gui, filename, DENEMO_FORMAT, FALSE);
+			file_saveas (gui, FALSE);
+		} else {    
+      gint status =
+				filesel_save (gui, filename, DENEMO_FORMAT, FALSE);
+			if(status==0)
+				 score_status(gui, FALSE);
       force_lily_refresh(gui);
     }
 }
@@ -937,29 +940,40 @@ void
 file_savewrapper (GtkAction * action, DenemoScriptParam *param)
 {
   DenemoGUI *gui = Denemo.gui;
-  file_save (NULL, gui);
+  
+	if(file_save (NULL, gui)) {
+		if(action) {
+			warningdialog("File Save **FAILED**");
+			score_status(gui, TRUE);
+		}	else {
+				if(param)
+					param->status = FALSE;
+			}	
+	}	
 }
 
 /**
  * if gui->filename exists saves gui to the filename  based on its extension
  * otherwise call saveas routine
  */
-void
+gint
 file_save (GtkWidget * widget, DenemoGUI * gui)
 {
+	gint ret;
   DenemoScore *si = gui->si;
   g_print ("READONLY %d\n", si->readonly);
   if ((gui->filename->len == 0)/* || (si->readonly == TRUE)*/)
     /* No filename's been given or is opened from template */
     file_saveas (gui, FALSE);
   else
-    save_in_format(DENEMO_FORMAT, gui, NULL);
+    ret = save_in_format(DENEMO_FORMAT, gui, NULL);
   
   /*Save parts as lilypond files*/   
   if(Denemo.prefs.saveparts)
     export_lilypond_parts(gui->filename->str,gui);
   
   score_status(gui, FALSE);
+  return ret;
 }
 
 static void
@@ -970,8 +984,11 @@ file_dialog_response(GtkWidget *dialog, gint response_id, struct FileDialogData
     gchar *file_name =
       gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
     if (replace_existing_file_dialog
-          (file_name, GTK_WINDOW (Denemo.window), data->format_id)){
-      filesel_save (gui, file_name, data->format_id, data->template);
+          (file_name, GTK_WINDOW (Denemo.window), data->format_id)) {
+			gint status =
+				filesel_save (gui, file_name, data->format_id, data->template);
+			if(status==0)
+				 score_status(gui, FALSE);
       force_lily_refresh(gui);
     }
     g_free (file_name);
@@ -981,10 +998,8 @@ file_dialog_response(GtkWidget *dialog, gint response_id, struct FileDialogData
 }
 
 
-#define FILE_SAVE_DIALOG(description)\
+#define FILE_SAVE_DIALOG(description, template)\
   GtkWidget *file_selection;\
-  GtkWidget *label;\
-  GtkWidget *hbox;\
   GtkFileFilter *filter;\
   file_selection = gtk_file_chooser_dialog_new (description,\
 						GTK_WINDOW (Denemo.window),\
@@ -994,7 +1009,7 @@ file_dialog_response(GtkWidget *dialog, gint response_id, struct FileDialogData
 						GTK_STOCK_SAVE,\
 						GTK_RESPONSE_ACCEPT, NULL);\
   /*set default folder for saving */\
-  set_current_folder(file_selection, gui, SAVE_NORMAL);\
+  set_current_folder(file_selection, gui, template?SAVE_TEMPLATE:SAVE_NORMAL);\
   \
   /* assign title */ \
   gchar *title = get_scoretitle();\
@@ -1025,7 +1040,7 @@ file_export (DenemoGUI * gui, FileFormatNames format_id)
 {
   gchar *description = g_strconcat(_("Export As "), FORMAT_DESCRIPTION(format_id), NULL);
   DenemoSaveType  template = FALSE;
-  FILE_SAVE_DIALOG(description)
+  FILE_SAVE_DIALOG(description, template)
   g_free(description);
 }
 
@@ -1038,7 +1053,7 @@ void
 file_saveas (DenemoGUI * gui, DenemoSaveType  template)
 {
   gint format_id = DENEMO_FORMAT;
-  FILE_SAVE_DIALOG(_("Save As"))
+  FILE_SAVE_DIALOG(_("Save As"), template)
 }
 
 /**
@@ -1053,6 +1068,7 @@ file_newwrapper (GtkAction * action, DenemoScriptParam *param)
   if(param==NULL)
     param = &dummy;
   DenemoGUI *gui = Denemo.gui;
+  g_signal_handlers_block_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
   if (gui->notsaved)
     {
       if (confirmbox (gui)) {
@@ -1060,17 +1076,22 @@ file_newwrapper (GtkAction * action, DenemoScriptParam *param)
       }
       else {
         param->status = FALSE;
+        g_signal_handlers_unblock_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
         return;
       }
     }
   else {
       deletescore(NULL, gui);
   }
+  deleteSchemeText();
+  gui->has_script = FALSE;
   set_enharmonic_position(0);
   if(Denemo.printarea) 
     g_object_set_data(G_OBJECT(Denemo.printarea), "printviewupdate", (gpointer)G_MAXUINT);
   score_status(gui, FALSE);
   param->status = TRUE;
+  g_signal_handlers_unblock_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
+
 }
 
 
