@@ -272,6 +272,7 @@ parseDirective (xmlNodePtr parentElem, xmlNsPtr ns,
     DO_DIREC(postfix);
     DO_DIREC(display); 
     DO_DIREC(midibytes);
+    DO_DIREC(grob);
     DO_INTDIREC(override);
     DO_INTDIREC(minpixels);
     DO_INTDIREC(x);
@@ -306,6 +307,7 @@ parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn, DenemoDir
     DO_DIREC(graphic_name);
 
     DO_DIREC(midibytes);
+    DO_DIREC(grob);
     DO_INTDIREC(override);
     DO_INTDIREC(minpixels);
     DO_INTDIREC(x);
@@ -387,8 +389,8 @@ parseWidgetDirectives (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn, GtkMenu*
     DenemoDirective *directive = (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
     parseWidgetDirective(childElem, ns, fn, directive, menu);
     directives = g_list_append(directives, directive);
-    if(menu)
-	g_object_set_data(G_OBJECT(directive->widget), "directives-pointer", (gpointer)directives_pointer);//FIXME this const string has to match with lilydirectives.c
+    if(directives_pointer)
+			g_object_set_data(G_OBJECT(directive->widget), "directives-pointer", (gpointer)directives_pointer);//FIXME this const string has to match with lilydirectives.c
   }
   return directives;
 }
@@ -930,9 +932,9 @@ parseBaseChord (xmlNodePtr chordElem, xmlNsPtr ns, DenemoScore * si)
 	  show = FALSE;
 	}
     }
-
-  gboolean grace= (xmlGetProp (chordElem, (xmlChar *) "grace")!=NULL);//we only store this for grace notes
-    
+  gchar *grace_type = xmlGetProp (chordElem, (xmlChar *) "grace");
+  gint grace= (grace_type?(strcmp(grace_type, "true")?ACCIACCATURA:GRACED_NOTE):0);//we only store this for grace notes
+  g_free(grace_type);
 
   /*
    * First, in order to actually create a chord object, we must figure out the
@@ -997,8 +999,8 @@ parseBaseChord (xmlNodePtr chordElem, xmlNsPtr ns, DenemoScore * si)
     }
 DenemoObject *chordObj =
   show?newchord (baseDuration, numDots, 0):hidechord(newchord (baseDuration, numDots, 0));
- if(grace)
-   ((chord *) chordObj->object)->is_grace = GRACED_NOTE;
+ 
+   ((chord *) chordObj->object)->is_grace = grace;
 
 
   FOREACH_CHILD_ELEM (childElem, chordElem)  {
@@ -1455,6 +1457,7 @@ parseLilyDir (xmlNodePtr LilyDirectiveElem, xmlNsPtr ns, DenemoScore *si)
   GET_STR_FIELD(tag);
   GET_STR_FIELD(display);
   GET_STR_FIELD(midibytes);
+  GET_STR_FIELD(grob);
   GET_STR_FIELD(graphic_name);
   GET_STR_FIELD(prefix);
   if(thedirective->graphic_name && thedirective->graphic_name->len)
@@ -1604,37 +1607,6 @@ parseTupletEnd (xmlNodePtr tupletStartElem, xmlNsPtr ns, tuplet *tup)
 
 
 
-/**
- * Parse the given <grace-start> into a grace-start DenemoObject.
- * @param graceStartElem the XML node to process
- * @param ns the Denemo XML namespaces
- * @param si the DenemoScore to populate 
- * 
- * @return the new DenemoObject
- */
-static DenemoObject *
-parseGraceStart (xmlNodePtr graceStartElem, xmlNsPtr ns, DenemoScore * si)
-{
-  gchar *onBeatStr =
-    (gchar *) xmlGetProp (graceStartElem, (xmlChar *) "on-beat");
-  gboolean onBeat = FALSE;
-  DenemoObject *result = newgracestart ();
-
-  if (onBeatStr != NULL)
-    {
-      if (!strcmp (onBeatStr, "true"))
-	onBeat = TRUE;
-      else if (!strcmp (onBeatStr, "false"))
-	onBeat = FALSE;
-      else
-	g_warning ("Invalid value \"%s\" for \"on-beat\" attribute on "
-		   "<grace-start> element; defaulting to \"false\"",
-		   onBeatStr);
-    }
-  ((grace *) result->object)->on_beat = onBeat;
-
-  return result;
-}
 
 /**
  * Parse the given <thumbnail> into the thumbnail  DenemoSelection.
@@ -1874,7 +1846,7 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
   gint bpm;
   // gchar *title, *subtitle, *composer, *poet, *meter, *arranger, *opus;
   // gchar *instrument, *dedication, *piece, *head, *copyright, *footer,
-  gchar *title, *tagline, *mvmnt_header, *markup_before, *markup_after, *layout_markup;
+  gchar *title, *mvmnt_header, *markup_before, *markup_after, *layout_markup;
 
   FOREACH_CHILD_ELEM (childElem, scoreInfoElem)
   {
@@ -2633,11 +2605,11 @@ parseMeasures (xmlNodePtr measuresElem, xmlNsPtr ns, DenemoScore * si)
 	         } */
 	      else if (ELEM_NAME_EQ (objElem, "grace-end"))
 		{
-		  curObj = newgraceend ();
+		  g_warning(_("Obsolete form, use earlier Denemo version to convert"));//curObj = newgraceend ();
 		}
 	      else if (ELEM_NAME_EQ (objElem, "grace-start"))
 		{
-		  curObj = parseGraceStart (objElem, ns, si);
+		  g_warning(_("Obsolete form, use earlier Denemo version to convert"));//curObj = parseGraceStart (objElem, ns, si);
 		}
 	      else if (ELEM_NAME_EQ (objElem, "key-signature"))
 		{
@@ -2858,15 +2830,15 @@ parseScore (xmlNodePtr scoreElem, xmlNsPtr ns, DenemoGUI * gui, ImportType type)
 
   childElem = getXMLChild (scoreElem, "header-directives", ns);
   if (childElem != 0)
-    si->header.directives = parseWidgetDirectives(childElem, ns, (gpointer)header_directive_put_graphic, NULL, NULL);
+    si->header.directives = parseWidgetDirectives(childElem, ns, (gpointer)header_directive_put_graphic, NULL, &(si->header.directives));
 
   childElem = getXMLChild (scoreElem, "layout-directives", ns);
   if (childElem != 0)
-    si->layout.directives = parseWidgetDirectives(childElem, ns, (gpointer)layout_directive_put_graphic, NULL, NULL);
+    si->layout.directives = parseWidgetDirectives(childElem, ns, (gpointer)layout_directive_put_graphic, NULL, &(si->layout.directives));
 
   childElem = getXMLChild (scoreElem, "movementcontrol-directives", ns);
   if (childElem != 0)
-    si->movementcontrol.directives = parseWidgetDirectives(childElem, ns, (gpointer)movementcontrol_directive_put_graphic, NULL, NULL);
+    si->movementcontrol.directives = parseWidgetDirectives(childElem, ns, (gpointer)movementcontrol_directive_put_graphic, NULL, &(si->movementcontrol.directives));
 
   childElem = getXMLChild (scoreElem, "sources", ns);
   if (childElem != 0)
@@ -3078,6 +3050,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
     case REPLACE_SCORE:
       free_movements(gui);
       deleteSchemeText();
+      gui->has_script = FALSE;
       /* this is dependent on the order of elements, which is not strictly correct */
       FOREACH_CHILD_ELEM(childElem, rootElem){
 	
@@ -3111,10 +3084,10 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
 	      parseSourceFileElem (childElem, ns, gui);
 	    } else
 	      if (ELEM_NAME_EQ (childElem, "scoreheader-directives")){
-		gui->scoreheader.directives = parseWidgetDirectives(childElem, ns, (gpointer)scoreheader_directive_put_graphic, NULL, NULL);
+					gui->scoreheader.directives = parseWidgetDirectives(childElem, ns, (gpointer)scoreheader_directive_put_graphic, NULL, &(gui->scoreheader.directives));
 	      } else
 		if (ELEM_NAME_EQ (childElem, "paper-directives")){
-		  gui->paper.directives = parseWidgetDirectives(childElem, ns, (gpointer)paper_directive_put_graphic, NULL, NULL);
+		  gui->paper.directives = parseWidgetDirectives(childElem, ns, (gpointer)paper_directive_put_graphic, NULL, &(gui->paper.directives));
 		} else
 		  if (ELEM_NAME_EQ (childElem, "custom_scoreblock")){
 		    gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
@@ -3173,7 +3146,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
     case REPLACE_SCORE:
       free_score (gui);
       if(gui->movements)
-	g_list_free(gui->movements);/*FIXME free all the other si */
+			g_list_free(gui->movements);/*FIXME free all the other si */
       gui->movements = NULL;
       init_score(gui->si, gui);
       gui->si->currentstaffnum = 0;
@@ -3192,11 +3165,12 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
        gtk_widget_hide(gui->si->lyricsbox);
     prev_movement(NULL, NULL);
   }
-  if(gui->si->lyricsbox)
+  if(gui->si->lyricsbox) {
     if(!Denemo.prefs.lyrics_pane)
       gtk_widget_hide(gui->si->lyricsbox);
     else
       gtk_widget_show(gui->si->lyricsbox);
+	}
   score_status(gui, FALSE);
 
  cleanup:
@@ -3211,6 +3185,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
   }
   sXMLIDToElemMap = NULL;
   //g_print("Number of movements %d\n", g_list_length(gui->movements));
+  reset_movement_numbers(gui);
   return ret;
 }
 
