@@ -13,15 +13,6 @@
 
 static GtkWidget *DummyVerse;/* a non-existent verse */
 
-static gboolean lyric_keypress(GtkWidget *w, GdkEventKey *event) {
-DenemoGUI *gui = Denemo.gui;
- if(gtk_text_buffer_get_modified(gtk_text_view_get_buffer(GTK_TEXT_VIEW(w)))) {
-   score_status(Denemo.gui, TRUE);
-   gtk_widget_queue_draw (Denemo.scorearea);
-   gtk_text_buffer_set_modified(gtk_text_view_get_buffer(GTK_TEXT_VIEW(w)), FALSE);
- }
- return FALSE;
-}
 gboolean lyric_change(GtkTextBuffer *buffer) {
   DenemoGUI *gui = Denemo.gui;
   score_status(gui, TRUE);
@@ -69,7 +60,7 @@ GtkWidget * add_verse_to_staff(DenemoScore *si, DenemoStaff *staff) {
       si->measurewidth = DENEMO_INITIAL_MEASURE_WIDTH*3;
   } else {
     GtkWidget *w = staff->verses->data;
-    notebook = gtk_widget_get_parent(w);
+    notebook = gtk_widget_get_parent(gtk_widget_get_parent(w));
   }
   // if(staff->currentverse)    
   //  gtk_widget_hide(staff->currentverse->data); 
@@ -110,7 +101,7 @@ DenemoScore *si = gui->si;
    DenemoStaff *staff = si->currentstaff->data;
    if(staff->currentverse) {
      staff->verses = g_list_remove_link(staff->verses, staff->currentverse);
-     gtk_widget_destroy(staff->currentverse->data);
+     gtk_widget_destroy(gtk_widget_get_parent(staff->currentverse->data));
      staff->currentverse = staff->verses;
      signal_structural_change(gui);
      score_status(gui, TRUE);
@@ -146,7 +137,7 @@ static gchar *lyric_iterator(GtkWidget *textview, gint count) {
   static  const gchar *next;
   static gchar *lyrics;
   static GString *gs;
-  static start_count;
+  static gint start_count;
   if(gs==NULL)
     gs = g_string_new("");
   if(textview==NULL) {
@@ -195,17 +186,17 @@ void install_lyrics_preview(DenemoScore *si, GtkWidget *top_vbox){
 /* hide the notebook of verses for the current staff */
 void hide_lyrics(void) {
 DenemoGUI *gui = Denemo.gui;
-DenemoScore *si = gui->si;
- if(gui->si->currentstaff && ((DenemoStaff *)gui->si->currentstaff->data)->currentverse)
-   gtk_widget_hide(gtk_widget_get_parent(((DenemoStaff *)gui->si->currentstaff->data)->currentverse->data));
+ if(gui->si->currentstaff && ((DenemoStaff *)gui->si->currentstaff->data)->verses)
+   gtk_widget_hide(gtk_widget_get_parent(gtk_widget_get_parent(((DenemoStaff *)gui->si->currentstaff->data)->verses->data)));//hide the notebook
 }
 
-/* show the notebook of verses for the current staff */
+/* show the notebook of verses for the current staff hide all others*/
 void show_lyrics(void) {
 DenemoGUI *gui = Denemo.gui;
 DenemoScore *si = gui->si;
- if(si->currentstaff && ((DenemoStaff *)si->currentstaff->data)->currentverse)
-   gtk_widget_show(gtk_widget_get_parent(((DenemoStaff *)si->currentstaff->data)->currentverse->data));
+ if(si->currentstaff && ((DenemoStaff *)si->currentstaff->data)->verses)
+   gtk_widget_show(gtk_widget_get_parent(gtk_widget_get_parent(((DenemoStaff *)si->currentstaff->data)->verses->data)));//show the notebook
+  select_lyrics();
 }
 
 /* hide the notebooks of verses for the non-current staffs */
@@ -215,7 +206,7 @@ DenemoScore *si = gui->si;
  GList *current = si->thescore;
  for(;current;current = current->next) {
    if(current != si->currentstaff && ((DenemoStaff *)current->data)->verses)
-       gtk_widget_hide(gtk_widget_get_parent(((DenemoStaff *)current->data)->verses->data));
+       gtk_widget_hide(gtk_widget_get_parent(gtk_widget_get_parent(((DenemoStaff *)current->data)->verses->data)));//hide the notebook
  }
 }
 
@@ -251,3 +242,46 @@ gboolean put_lyrics_for_current_verse(DenemoStaff *thestaff, gchar *text) {
   else
     return FALSE;
 }
+
+#ifdef VERSE_NAVIGATION_CODE
+//return the verse number for the current verse (starting at 1) or 0 if none
+gint get_current_verse_number(void) {
+DenemoGUI *gui = Denemo.gui;
+ if(gui->si->currentstaff) {
+	DenemoStaff *thestaff = ((DenemoStaff *)gui->si->currentstaff->data);
+	if(thestaff->verses)	
+		return 1+g_list_index(thestaff->verses, thestaff->currentverse);
+
+	}
+ }
+return 0;
+}
+
+gboolean set_current_verse(gint number) {
+DenemoGUI *gui = Denemo.gui;
+ if(gui->si->currentstaff) {
+	DenemoStaff *thestaff = ((DenemoStaff *)gui->si->currentstaff->data);
+	if(thestaff->verses) {
+		GList *g = g_list_nth(thestaff->verses, number-1);
+		if(g) {
+			thestaff->currentverse = g;
+			emit_signal("switch-page",....
+			return TRUE;
+			}		
+	}
+}
+#endif
+
+gchar *get_lyrics_for_verse_num(gint number) {
+	DenemoGUI *gui = Denemo.gui;
+  if(gui->si->currentstaff) {
+		DenemoStaff *thestaff = ((DenemoStaff *)gui->si->currentstaff->data);
+		if(thestaff->verses) {
+		GList * verse = g_list_nth(thestaff->verses, number-1);
+		if(verse)
+		return get_text_from_view(verse->data);
+		}
+	}
+ return NULL;
+}
+
