@@ -94,6 +94,7 @@ sigchld_handler (gint num)
         {
           exitstatus = WEXITSTATUS (status);
 
+
           fprintf (stderr,
                    _("Parent: child exited, pid = %d, exit status = %d\n"),
                    (int) pid, exitstatus);
@@ -297,9 +298,11 @@ main (int argc, char *argv[])
   gchar *guile = g_build_filename (prefix, "share", "guile", NULL);
   gchar *guile_1_8 = g_build_filename (guile, "1.8", NULL);
   gchar *lilypond_current_scm = g_build_filename (prefix, "share", "lilypond", "current", "scm", NULL);
+  gchar *denemo_scm = g_build_filename (prefix, "share", "denemo", "actions", NULL);
+  gchar *denemo_modules_scm = g_build_filename (prefix, "share", "denemo", "actions", "denemo-modules", NULL);
   if (g_file_test (guile, G_FILE_TEST_EXISTS))
     {
-      gchar *guile_path = g_strconcat (guile, ";", guile_1_8, ";", lilypond_current_scm, NULL);
+      gchar *guile_path = g_strconcat (guile, ";", guile_1_8, ";", denemo_scm, ";", denemo_modules_scm,";",lilypond_current_scm, NULL);
       g_setenv ("GUILE_LOAD_PATH", guile_path, TRUE);//FIXME TRUE means we overwrite any installed version of lilyponds scm, FALSE risks not putting denemos scm in the path...
       g_print ("Setting GUILE_LOAD_PATH=%s\n", guile_path);
     }
@@ -347,7 +350,7 @@ main (int argc, char *argv[])
 #else
 
 
-#ifdef UNUSED__APPLE
+#ifdef __APPLE__
   //FIXME if this works, remove the duplication with windows case
  {
   gchar *prefix = g_build_filename (g_path_get_dirname(get_bin_dir()), "..", NULL);      
@@ -414,13 +417,23 @@ main (int argc, char *argv[])
       }
 #else
 
-  gchar *prefix = g_build_filename (get_bin_dir(), "..", NULL); 
-  add_font_directory (DATAROOTDIR "/fonts");
+  gchar *prefix = g_build_filename (get_prefix_dir(), NULL);
+  add_font_directory (g_build_filename (get_data_dir(), "/fonts", NULL));
+
+  gchar *fontpath = g_build_filename (prefix, "share", "fonts", "truetype","denemo", "feta.ttf", NULL);
+  g_setenv ("LILYPOND_VERBOSE", "1", FALSE);
+  add_font_file(fontpath);
+  fontpath = g_build_filename (prefix, "share", "fonts", "truetype","denemo", "Denemo.ttf", NULL);
+  add_font_file(fontpath);
+  fontpath = g_build_filename (prefix, "share", "fonts", "truetype","denemo", "emmentaler.ttf", NULL);
+  add_font_file(fontpath);
 #endif /* end of not windows and not APPLE */
 
 
 
-  append_to_path("GUILE_LOAD_PATH", g_build_filename(prefix, "share", "denemo", NULL));  
+  append_to_path("GUILE_LOAD_PATH", g_build_filename(prefix, "share", "denemo", "actions", NULL));  
+  append_to_path("GUILE_LOAD_PATH", g_build_filename(prefix, "share", "denemo", "actions", "denemo-modules", NULL));  
+
 
   
 #endif /* end of else not windows */
