@@ -45,11 +45,11 @@ static GQueue midi_queue = G_QUEUE_INIT;
 static gint put_get_midiqueue(gint midi) {
   if(g_queue_is_empty(&midi_queue))
     return midi;
-  g_queue_push_tail(&midi_queue, (gpointer)midi);
+  g_queue_push_tail(&midi_queue, GINT_TO_POINTER(midi));
   return (gint)g_queue_pop_head(&midi_queue);
 }
 static void put_midiqueue(gint midi) {
-  g_queue_push_tail(&midi_queue, (gpointer)midi);
+  g_queue_push_tail(&midi_queue, GINT_TO_POINTER(midi));
 }
 
 static gint get_midiqueue(void) {
@@ -120,7 +120,7 @@ static gboolean update_playbutton_callback(gboolean paused) {
 
 void stop_playing() {
   update_position(NULL);
-  g_idle_add_full(G_PRIORITY_HIGH_IDLE, (GSourceFunc)update_playbutton_callback, (gpointer)is_paused(), NULL);
+  g_idle_add_full(G_PRIORITY_HIGH_IDLE, (GSourceFunc)update_playbutton_callback, GINT_TO_POINTER(is_paused()), NULL);
   playing = FALSE;
   play_until = -G_MAXDOUBLE;
   if(Denemo.gui->si && Denemo.gui->si->recorded_midi_track) {
@@ -446,7 +446,7 @@ static gint midiaction(gint notenum) {
 	    chord *thechord = (chord *)  curObj->object;
 	    is_tied = thechord->is_tied;
 	    
-#define check_midi_note(a,b,c,d) ((a->mid_c_offset==b)&&(a->enshift==c))?playnote(a,curstaffstruct->midi_channel):gdk_beep();
+//#define check_midi_note(a,b,c,d) ((a->mid_c_offset==b)&&(a->enshift==c))?playnote(a,curstaffstruct->midi_channel):gdk_beep();
 
 	    //g_print("check %d %d %d %d %d\n", a->mid_c_offset, a->enshift, b, c, d);
 	    if( (Denemo.keyboard_state&CHECKING_MASK) && thechord->notes) {
@@ -689,7 +689,7 @@ gboolean intercept_midi_event(gint *midi) {
    // return FALSE;
     set_midi_capture(FALSE);
     g_queue_clear(&midi_queue);
-   
+   return FALSE;
   }
   if(g_queue_is_empty(&midi_queue)) {
   divert_midi_event = midi;
@@ -702,6 +702,7 @@ gboolean intercept_midi_event(gint *midi) {
     *midi =  (0xFFFFFF & get_midiqueue());
      //g_print("getting from queue %x\n", *midi);
   }
+  return TRUE;
 }
 
 
