@@ -247,7 +247,8 @@ pi->measure_number >= rightmeasurenum);
 		  /* The below makes clicking to get the object at the end of
 		     a measure (instead of appending after it) require
 		     precision.  This may be bad; tweak me if necessary.  */
-		  if (x_to_explain > current->x + current->minpixelsalloted)
+		  if ((x_to_explain > current->x + current->minpixelsalloted) ||
+			(x_to_explain > GPOINTER_TO_INT (mwidthiterator->data) - current->minpixelsalloted/3))//if closer to barline than object center
 		    pi->offend = TRUE, pi->cursor_x++;
 		}
 	    }
@@ -585,9 +586,9 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
     }  else  if(event->x<KEY_MARGIN+key+cmajor) {
       if(left) {
 	if(offset<STAFF_HEIGHT/2)
-	  call_out_to_guile("(d-IncrementKeysig 1)");
+	  call_out_to_guile("(d-SharpenInitialKeysigs)");
 	else
-	  call_out_to_guile("(d-IncrementKeysig -1)");
+	  call_out_to_guile("(d-FlattenInitialKeysigs)");
       } else
       popup_menu("/InitialKeyEditPopup");
       return TRUE;
@@ -600,15 +601,14 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 
 
   if(left) {
-    // if(!(GDK_CONTROL_MASK&event->state))
+     if(!(GDK_SHIFT_MASK&event->state))
       gui->si->markstaffnum = 0;
-    //    else
-    //  calcmarkboundaries (gui->si);
      lh_down = TRUE;
- 
   } else {
-    if(gui->si->cursor_appending)
-    movecursorleft(NULL);//so that right click in appending position acts on previous object
+    if(gui->si->cursor_appending) {
+			popup_menu("/NoteAppendPopup");
+			return TRUE;
+		}
   }
   /* Redraw to show new cursor position, note a real draw is needed because of side effects on display*/
   //gtk_widget_draw (Denemo.scorearea, NULL);
