@@ -12,7 +12,7 @@
 #include "audiointerface.h"
 
 
-#define  DEFAULT_HIGH (4500.0)
+#define  DEFAULT_HIGH (1400.0)
 #define  DEFAULT_LOW (60.0)
 #define DEFAULT_TIMER_RATE (50)
 #define QUARTER_COMMA_MEAN_TONE "Quarter comma meantone"
@@ -779,7 +779,7 @@ static void display_pitch(double note, DenemoGUI *gui) {
 	gtk_widget_queue_draw(PR_indicator);
       }
     }
-/*     fprintf(stderr, "Pitch is %d %d\t", (int)(Freq2Pitch(note)+0.5), (int)note); */
+     //fprintf(stderr, "Pitch is %0.2f\t", note);
   }
 
 static gint measure_pitch_accurately (DenemoGUI *gui) {
@@ -1182,9 +1182,9 @@ GtkWidget *get_temperament_combo(void) {
 		    G_CALLBACK (temperament_changed_callback), list_store);
   //set_tuning();
   }
-  GtkWidget *cont = gtk_widget_get_parent(combobox);
-  if(cont)
-    gtk_container_remove(GTK_CONTAINER(cont), combobox);
+//  GtkWidget *cont = gtk_widget_get_parent(combobox);
+ // if(cont)
+ //   gtk_container_remove(GTK_CONTAINER(cont), combobox);
   return combobox;
 }
 
