@@ -99,18 +99,18 @@ initprefs ()
 #ifdef G_OS_WIN32
   ret->browser = g_string_new ("");//use file association
   ret->audioplayer = g_string_new ("");
-  ret->lilypath = g_string_new ("lilypond.exe");//We don't assume the file assoc works - we are installing this anyway to a known place,the option  neither lilypond-windows.exe nor the -dgui option are used
+  ret->lilypath = g_string_new (g_build_filename(get_bin_dir(), "lilypond-windows.exe", NULL));//We don't assume the file assoc works - we are installing this anyway to a known place,the option  neither lilypond-windows.exe nor the -dgui option are used
   ret->pdfviewer = g_string_new ("");
   ret->imageviewer = g_string_new ("");
-  ret->profile = g_string_new("Simple");
 #else /* !G_OS_WIN32 */
   ret->browser = g_string_new ("firefox");
   ret->audioplayer = g_string_new ("play");
   ret->lilypath = g_string_new ("lilypond");
   ret->pdfviewer = g_string_new ("evince");
   ret->imageviewer = g_string_new ("eog");
-  ret->profile = g_string_new("Arranger");
 #endif /* !G_OS_WIN32 */
+
+  ret->profile = g_string_new("Arranger");
   ret->denemopath = g_string_new (g_get_home_dir());
   ret->lilyversion = g_string_new ("");//meaning use installed LilyPond version
   ret->temperament = g_string_new("Equal");
@@ -124,7 +124,15 @@ initprefs ()
   ret->return_key_is_special = TRUE;
   ret->newbie = TRUE;
   ret->immediateplayback = TRUE;
-
+  ret->manualtypeset = FALSE;
+  ret->typesetrefresh = 10;
+  ret->typesettype = TYPESET_ALL_MOVEMENTS;
+  ret->firstmeasure = 4;
+  ret->firststaff = 4;
+  ret->lastmeasure = 4;
+  ret->laststaff = 4;
+  
+  
   ret->audio_driver = g_string_new("default");
   ret->midi_driver = g_string_new("default");
 #ifdef _HAVE_PORTAUDIO_
@@ -172,7 +180,7 @@ initprefs ()
   ret->quickshortcuts = TRUE;
   ret->progressbardecorations = TRUE;
   /* Read values from systemwide preferences file */
-
+  printf("\nsystemwide == %s\n", systemwide);
   readxmlprefsFile (systemwide);
 
   /* Read values from personal preferences file */
@@ -321,6 +329,14 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       
       READBOOLXMLENTRY(createclones)
       READBOOLXMLENTRY(immediateplayback)
+      READBOOLXMLENTRY(manualtypeset)
+      READINTXMLENTRY(typesetrefresh)
+      READINTXMLENTRY(typesettype)
+      READINTXMLENTRY(firstmeasure)
+      READINTXMLENTRY(firststaff)
+      READINTXMLENTRY(lastmeasure)
+      READINTXMLENTRY(laststaff)
+      
       READINTXMLENTRY(pitchspellingchannel)
       READINTXMLENTRY(pitchspellingprogram)
       READBOOLXMLENTRY(modal) 
@@ -335,6 +351,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READINTXMLENTRY(mode) 
   
       READBOOLXMLENTRY(strictshortcuts)
+      READBOOLXMLENTRY(menunavigation)
       READINTXMLENTRY(resolution)
       READDOUBLEXMLENTRY(display_refresh)
       READINTXMLENTRY(animation_steps)
@@ -348,8 +365,8 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READBOOLXMLENTRY(lilyentrystyle)
       READBOOLXMLENTRY(toolbar)
       READBOOLXMLENTRY(notation_palette)
-	READBOOLXMLENTRY(midi_in_controls)
-	READBOOLXMLENTRY(playback_controls)
+	    READBOOLXMLENTRY(midi_in_controls)
+	    READBOOLXMLENTRY(playback_controls)
       READBOOLXMLENTRY(console_pane)
       READBOOLXMLENTRY(lyrics_pane)
       READBOOLXMLENTRY(visible_directive_buttons)
@@ -406,10 +423,10 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 gboolean get_bool_pref(gchar *prefname) {
   if(*prefname == 0)
     return FALSE;
-  GETBOOLPREF(immediateplayback)
       GETBOOLPREF(autosave)
       GETBOOLPREF(createclones)
       GETBOOLPREF(immediateplayback)
+			GETBOOLPREF(manualtypeset)
       GETBOOLPREF(modal) 
       GETBOOLPREF(persistence) 
       GETBOOLPREF(cursor_highlight) 
@@ -419,6 +436,7 @@ gboolean get_bool_pref(gchar *prefname) {
       GETBOOLPREF(quickshortcuts) 
       GETBOOLPREF(startmidiin) 
       GETBOOLPREF(strictshortcuts)
+      GETBOOLPREF(menunavigation)
       GETBOOLPREF(overlays)
       GETBOOLPREF(enable_thumbnails)
       GETBOOLPREF(continuous)
@@ -447,6 +465,12 @@ return FALSE;
 gint get_int_pref(gchar *prefname) {
   if(*prefname == 0)
     return 0;
+      GETINTPREF(typesettype)
+      GETINTPREF(typesetrefresh)
+      GETINTPREF(firstmeasure)
+      GETINTPREF(firststaff)
+      GETINTPREF(lastmeasure)
+      GETINTPREF(laststaff)
       GETINTPREF(pitchspellingchannel)
       GETINTPREF(pitchspellingprogram)
       GETINTPREF(mode) 
@@ -590,7 +614,8 @@ readxmlprefs (gchar * xmlsource,  gboolean from_file)
   gint ret = -1;
   xmlDocPtr doc = NULL;
   xmlNodePtr rootElem;
-
+  if (from_file)
+    printf("\nxmlsource == %s\n", xmlsource);
   if(from_file) 
     doc = xmlParseFile (xmlsource);
   else
@@ -762,6 +787,14 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEBOOLXMLENTRY(createclones)
   WRITEBOOLXMLENTRY(lilyentrystyle)
   WRITEBOOLXMLENTRY(immediateplayback)
+  WRITEBOOLXMLENTRY(manualtypeset)
+  WRITEINTXMLENTRY(typesetrefresh)
+  WRITEINTXMLENTRY(typesettype)
+  WRITEINTXMLENTRY(firstmeasure)
+  WRITEINTXMLENTRY(firststaff)
+  WRITEINTXMLENTRY(lastmeasure)
+  WRITEINTXMLENTRY(laststaff)
+  
   WRITEINTXMLENTRY(pitchspellingchannel)
   WRITEINTXMLENTRY(pitchspellingprogram)
   WRITEBOOLXMLENTRY(modal)
@@ -774,12 +807,13 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEBOOLXMLENTRY(startmidiin)
   WRITEINTXMLENTRY(mode)
   WRITEBOOLXMLENTRY(strictshortcuts)
+  WRITEBOOLXMLENTRY(menunavigation)
   WRITEINTXMLENTRY(resolution)
   WRITEDOUBLEXMLENTRY(display_refresh)
   WRITEINTXMLENTRY(animation_steps)
-    WRITEINTXMLENTRY(tooltip_timeout)
-    WRITEINTXMLENTRY(tooltip_browse_timeout)
-    WRITEINTXMLENTRY(tooltip_browse_mode_timeout)
+  WRITEINTXMLENTRY(tooltip_timeout)
+  WRITEINTXMLENTRY(tooltip_browse_timeout)
+  WRITEINTXMLENTRY(tooltip_browse_mode_timeout)
   WRITEBOOLXMLENTRY(overlays)
   WRITEBOOLXMLENTRY(enable_thumbnails)
   WRITEBOOLXMLENTRY(continuous)
