@@ -17,174 +17,54 @@
 #include <stdlib.h>
 #include <string.h>
 #include "xmldefs.h"
-/**
- * List of MIDI instrument names
- * 
- */
-static gchar *instruments[] = {
-  "acoustic grand",
-  "bright acoustic",
-  "electric grand",
-  "honky-tonk",
-  "electric piano 1",
-  "electric piano 2",
-  "harpsichord",
-  "clav",
-  "celesta",
-  "glockenspiel",
-  "music box",
-  "vibraphone",
-  "marimba",
-  "xylophone",
-  "tubular bells",
-  "dulcimer",
-  "drawbar organ",
-  "percussive organ",
-  "rock organ",
-  "church organ",
-  "reed organ",
-  "accordion",
-  "harmonica",
-  "concertina",
-  "acoustic guitar (nylon)",
-  "acoustic guitar (steel)",
-  "electric guitar (jazz)",
-  "electric guitar (clean)",
-  "electric guitar (muted)",
-  "overdriven guitar",
-  "distorted guitar",
-  "guitar harmo(dinics",
-  "acoustic bass",
-  "electric bass (finger)",
-  "electric bass (pick)",
-  "fretless bass",
-  "slap bass 1",
-  "slap bass 2",
-  "synth bass 1",
-  "synth bass 2",
-  "violin",
-  "viola",
-  "cello",
-  "contrabass",
-  "tremolo strings",
-  "pizzicato strings",
-  "orchestral harp",
-  "timpani",
-  "string ensemble 1",
-  "string ensemble 2",
-  "synthstrings 1",
-  "synthstrings 2",
-  "choir aahs",
-  "voice oohs",
-  "synth voice",
-  "orchestra hit",
-  "trumpet",
-  "trombone",
-  "tuba",
-  "muted trumpet",
-  "french horn",
-  "brass section",
-  "synthbrass 1",
-  "synthbrass 2",
-  "soprano sax",
-  "alto sax",
-  "tenor sax",
-  "baritone sax",
-  "oboe",
-  "english horn",
-  "bassoon",
-  "clarinet",
-  "piccolo",
-  "flute",
-  "recorder",
-  "pan flute",
-  "blown bottle",
-  "skakuhachi",
-  "whistle",
-  "ocarina",
-  "lead 1 (square)",
-  "lead 2 (sawtooth)",
-  "lead 3 (calliope)",
-  "lead 4 (chiff)",
-  "lead 5 (charang)",
-  "lead 6 (voice)",
-  "lead 7 (fifths)",
-  "lead 8 (bass+lead)",
-  "pad 1 (new age)",
-  "pad 2 (warm)",
-  "pad 3 (polysynth)",
-  "pad 4 (choir)",
-  "pad 5 (bowed)",
-  "pad 6 (metallic)",
-  "pad 7 (halo)",
-  "pad 8 (sweep)",
-  "fx 1 (rain)",
-  "fx 2 (soundtrack)",
-  "fx 3 (crystal)",
-  "fx 4 (atmosphere)",
-  "fx 5 (brightness)",
-  "fx 6 (goblins)",
-  "fx 7 (echoes)",
-  "fx 8 (sci-fi)",
-  "sitar",
-  "banjo",
-  "shamisen",
-  "koto",
-  "kalimba",
-  "bagpipe",
-  "fiddle",
-  "shanai",
-  "tinkle bell",
-  "agogo",
-  "steel drums",
-  "woodblock",
-  "taiko drum",
-  "melodic tom",
-  "synth drum",
-  "reverse cymbal",
-  "guitar fret noise",
-  "breath noise",
-  "seashore",
-  "bird tweet",
-  "telephone ring",
-  "helicopter",
-  "applause",
-  "gunshot",
-  NULL
-};
-
-
-static const gchar *context_strings[] = {
-  NONE_STRING,
-  PIANO_START_STRING,
-  PIANO_END_STRING,
-  CHOIR_START_STRING,
-  CHOIR_END_STRING,
-  GROUP_START_STRING,
-  GROUP_END_STRING,
-  NULL
-};
-
+#include "midi.h"
+#include "selectops.h"
+#include "sf_util.h"
+#include "sffile.h"
 
 /**
- *  return GString with contexts contained in the passed DenemoContext
- *  caller must free the string.
+ * Convert illegal characters in soundfont
+ *
  */
-static GString *context_string (DenemoContext c) {
 
-  GString *s = g_string_new("");
-#define  APPEND(A,B)  if(c & A) g_string_append_printf(s, ":%s", B)
-  APPEND(DENEMO_PIANO_START, PIANO_START_STRING);
-  APPEND(DENEMO_PIANO_END, PIANO_END_STRING);
-  APPEND(DENEMO_CHOIR_START, CHOIR_START_STRING);
-  APPEND(DENEMO_CHOIR_END, CHOIR_END_STRING);
-  APPEND(DENEMO_GROUP_START, GROUP_START_STRING);
-  APPEND(DENEMO_GROUP_END, GROUP_END_STRING);
-  if(s->len==0)
-    g_string_append(s, NONE_STRING);
-  return s;
+static void ConvertIllegalChar(char *name){
+  gchar *p;
+  for (p = name; *p; p++) {
+    if (!isprint(*p) || *p == '{' || *p == '}')
+      *p = ' ';
+    else if (*p == '[')
+      *p = '(';
+    else if (*p == ']')
+      *p = ')';
+  }
 }
 
+/**
+ * parse soundfont file and give the preset list
+ *
+ */
+SFInfo *ParseSoundfont() {
+  FILE *fp;
+  static SFInfo sf;
+  int i;
+
+  if ((fp = fopen(Denemo.prefs.fluidsynth_soundfont->str, "r")) == NULL) {
+    printf("\ncan't open soundfont file\n");
+    return NULL;
+  }
+  if (load_soundfont(&sf, fp, TRUE)) {
+    printf("\nfail to read soundfont file\n");
+    return NULL;
+  }
+  fclose(fp);
+  for (i = 0; i < sf.npresets-1; i++) {
+    ConvertIllegalChar(sf.preset[i].hdr.name);
+  }
+  return &sf;
+}
+
+
+
 /**
  * Callback data used for setting the staffs properties
  * 
@@ -205,9 +85,6 @@ struct callbackdata
   GtkWidget *transposition;
   GtkWidget *volume;
   GtkWidget *mute_volume;
- 
-  
-
 };
 
 
@@ -221,9 +98,6 @@ set_properties (struct callbackdata *cbdata)
 {
 
   DenemoStaff *staffstruct = cbdata->staffstruct;
-  gint n;
-  gint err;
-
 #if GTK_MAJOR_VERSION==3
 #define ASSIGNTEXT(field) \
   if(cbdata->field)\
@@ -275,15 +149,24 @@ set_properties (struct callbackdata *cbdata)
   if(staffstruct->midi_instrument->len) {
     staffstruct->midi_prognum = get_midi_prognum(staffstruct);
     gint i;
-    for(i=0;instruments[i];i++) {
-      if(!strcmp(instruments[i],staffstruct->midi_instrument->str)) {
-	staffstruct->midi_prognum = i;
-	break;
-      }
-    }
-    if(staffstruct->midi_prognum != i)
-      ASSIGNNUMBER_1(midi_prognum);
+    SFInfo *sf = ParseSoundfont();
+    if(sf) {
+			for (i = 0; i < sf->npresets-1; i++) {
+				if(!strcmp(sf->preset[i].hdr.name, staffstruct->midi_instrument->str)) {
+					staffstruct->midi_prognum = sf->preset[i].preset;
+					printf("\nMIDI Instrument == %s \nMIDI PROGRAM == %d\n", 
+					staffstruct->midi_instrument->str, staffstruct->midi_prognum);
+					break;
+				}
+			}
+    free_soundfont(sf);
+	}
+ //   if(staffstruct->midi_prognum != i) /* I am not sure why this was necessary and if it is still needed*/
+ //     ASSIGNNUMBER_1(midi_prognum);
     ASSIGNNUMBER_1(midi_channel);
+    printf("\nAssigned MIDI Instrument == %s \nAssigned MIDI PROGRAM == %d i == %d\n", 
+		staffstruct->midi_instrument->str, staffstruct->midi_prognum, i);
+
   } else {
     ASSIGNNUMBER_1(midi_prognum);
     ASSIGNNUMBER_1(midi_channel);
@@ -316,26 +199,21 @@ staff_properties_change (void)
   GtkWidget *entrywidget;
   static GString *entrycontent;
   GList *instrument_list = NULL;
-  GList *context_list = NULL;
   static struct callbackdata cbdata;
+  gint i;
   
   if (!instrument_list)
     {
-      int i=0;
-      instrument_list = g_list_append (instrument_list, "");
-      do {
-	   instrument_list = g_list_append (instrument_list, instruments[i++]);
-      } while (instruments[i]);
-    }
+      SFInfo *sf = ParseSoundfont();
+      if(sf) {
+				for (i = 0; i < sf->npresets-1; i++) {
+					instrument_list = g_list_append (instrument_list, g_strdup ((gchar *) sf->preset[i].hdr.name));
+				}
+      free_soundfont(sf);
+			}
+		}
+
 
-  if (!context_list)
-    {
-      int i=0;
-      while (context_strings[i++])
-	{
-	  context_list = g_list_append (context_list, (gpointer) (context_strings[i]?context_strings[i]:"None"));
-	}
-    }
 
     {
       gui = Denemo.gui;
@@ -353,7 +231,7 @@ staff_properties_change (void)
     {
       entrycontent = g_string_new (NULL);
     }
- 
+  
   dialog = gtk_dialog_new_with_buttons (_("Staff Properties"), GTK_WINDOW(Denemo.window),
 					(GtkDialogFlags)
 					(GTK_DIALOG_MODAL |
@@ -373,7 +251,6 @@ staff_properties_change (void)
 		                                       _(thelabel));
 
 #define TEXTENTRY(thelabel, field) \
-  GtkWidget *field;\
   hbox = gtk_hbox_new (FALSE, 8);\
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
   label = gtk_label_new (_(thelabel));\
@@ -389,7 +266,7 @@ staff_properties_change (void)
   GtkWidget *field;\
   hbox = gtk_hbox_new (FALSE, 8);\
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
-  label = gtk_label_new (thelabel);\
+  label = gtk_label_new (_(thelabel));\
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
   field = gtk_spin_button_new_with_range (min, max, 1.0);\
@@ -401,7 +278,7 @@ staff_properties_change (void)
   GtkWidget *field;\
   hbox = gtk_hbox_new (FALSE, 8);\
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);\
-  label = gtk_label_new (thelabel);\
+  label = gtk_label_new (_(thelabel));\
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);\
   field = gtk_spin_button_new_with_range (min, max, 1.0);\
@@ -412,13 +289,13 @@ staff_properties_change (void)
 #define BOOLEANENTRY(thelabel, field) \
   GtkWidget *field;\
   field =\
-    gtk_check_button_new_with_label (thelabel); \
+    gtk_check_button_new_with_label (_(thelabel)); \
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (field),\
 		                                    staffstruct->field);\
     gtk_box_pack_start (GTK_BOX (main_vbox), field, FALSE, TRUE, 0);\
     cbdata.field = field;
 #if GTK_MAJOR_VERSION==3
- #define COMBOBOXENTRY(thelabel, field, thelist, index) \
+ #define COMBOBOXENTRY(thelabel, field, thelist, setstring) \
   GtkWidget *field;\
   hbox = gtk_hbox_new (FALSE, 8);\
   gtk_container_add (GTK_CONTAINER(main_vbox), hbox);	\
@@ -426,10 +303,14 @@ staff_properties_change (void)
   gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);\
   gtk_container_add (GTK_CONTAINER(hbox), label);   \
   field = gtk_combo_box_text_new ();\
-  gint i;\
-  for(i=0;i<G_N_ELEMENTS(thelist);i++)\
-    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT(field), thelist[i]);\
-  gtk_combo_box_set_active(GTK_COMBO_BOX_TEXT (field),index);\
+  i=0;\
+  while (thelist){\
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT(field), (gchar *) thelist->data);\
+      if (!g_strcmp0 (thelist->data, setstring->str))\
+	gtk_combo_box_set_active(GTK_COMBO_BOX_TEXT (field),i);\
+    i++;\
+    thelist=thelist->next;\
+  }\
   gtk_container_add (GTK_CONTAINER(hbox), field);\
   cbdata.field = field;
 #else
@@ -454,29 +335,10 @@ staff_properties_change (void)
   INTENTRY_LIMITS("Space below:", space_below, 0, MAXEXTRASPACE); 
   INTENTRY_LIMITS("Number of Lines:", no_of_lines, 1, 5);
 
-  
-  /*print appearance tab */
-  // NEWPAGE("Printout Appearance");
-
-  
-  //GString *s = context_string(staffstruct->context);
-  // g_print("\ncontext string = %s\n",s->str);
-  //  COMBOBOXENTRY("Context:", context, context_list, s);
-  // g_string_free(s, TRUE); 
  
   /* MIDI tab */
   NEWPAGE("MIDI");
-#if GTK_MAJOR_VERSION==3
-  // FIXME should probably be in seperate function 
-  gint index=0,z=0;
-  for(z=0;instruments[z];z++){
-    if (!g_strcmp0 (instruments[z], staffstruct->midi_instrument->str))\
-      index = z;
-  }
-  COMBOBOXENTRY("MIDI Instrument:", midi_instrument, instruments, index);
-#else
   COMBOBOXENTRY("MIDI Instrument:", midi_instrument, instrument_list, staffstruct->midi_instrument);
-#endif
   INTENTRY_LIMITS("Transposition:", transposition, -30, 30);
   BOOLEANENTRY("Mute", mute_volume);
   INTENTRY_LIMITS("Volume:", volume, 0, 127);
@@ -540,6 +402,16 @@ void staff_properties_change_cb (GtkAction *action, DenemoScriptParam * param) {
        g_string_printf(param->string, "%d", staff->transposition);
      param->status = TRUE;
    }
+   if(*query) if(!strcmp("midi_channel", query)) {
+       g_string_printf(param->string, "%d", staff->midi_channel);
+     param->status = TRUE;
+   }  
+   if(*query) if(!strcmp("midi_prognum", query)) {
+       g_string_printf(param->string, "%d", staff->midi_prognum);
+     param->status = TRUE;
+   }  
+ 
+   
    return;
  }
  take_snapshot();
