@@ -28,7 +28,7 @@
 #endif
 #include "pitchentry.h"
 
-#ifdef UNUSED__APPLE
+#ifdef _MACH_O_
 #include <mach-o/dyld.h>
 #endif
 
@@ -135,18 +135,22 @@ warningdialog (gchar * msg)
  * @param msg message to display
  * @return none
  */
-void
+GtkWidget *
 infodialog (gchar * msg)
 {
   GtkWidget *dialog;
   dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window),
 				   GTK_DIALOG_DESTROY_WITH_PARENT,
 				   GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", msg);
+#ifdef G_OS_WIN32
+	gtk_window_set_resizable(GTK_WINDOW(dialog), TRUE);	//needed on windows because of a bug, not all text can be seen.	
+#endif	   
   g_signal_connect_swapped (dialog, "response",
-			    G_CALLBACK (gtk_widget_destroy),
+			    G_CALLBACK (gtk_widget_hide),
 			    dialog);
   gtk_window_set_keep_above(GTK_WINDOW (dialog), TRUE);
   gtk_widget_show_all(dialog);
+  return dialog;
 }
 
 /* data stucture to contain Progressbar 
@@ -198,12 +202,13 @@ progressbar (gchar *msg)
     pdata = &progress_data;
 
     /* Replace GTK_WINDOW_TOPLEVEL with GTK_WINDOW_POPUP
-    * to have it witout window decoration. 
+    * to have it without window decoration. 
     */
     if (Denemo.prefs.progressbardecorations)
       pdata->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     else
       pdata->window = gtk_window_new (GTK_WINDOW_POPUP);
+    gtk_window_set_accept_focus (GTK_WINDOW (pdata->window), FALSE); //FIXME this is only a hint; perhaps we should embed the progress bar in the status line...
     gtk_window_set_title (GTK_WINDOW (pdata->window), _("Progress")); 
     gtk_widget_set_tooltip_text(pdata->window, _("This indicates the the LilyPond typsetter is still working on setting the Denemo score. This can take a long time, particularly for polyphony where voices must not collide. You can continue editing while the typsetting is taking place.\nKill this window if you want to re-start the typesetting e.g. after fixing a mistake you just spotted."));
     vbox = gtk_vbox_new (FALSE, 5);
@@ -211,6 +216,7 @@ progressbar (gchar *msg)
     gtk_widget_show (vbox);
 
     pdata->pbar = gtk_progress_bar_new();
+    
     gtk_container_add (GTK_CONTAINER (vbox), pdata->pbar);
     gtk_widget_show(pdata->pbar);
   }
@@ -300,12 +306,13 @@ drawfetachar_cr (cairo_t * cr, gunichar uc, double x, double y)
 
 void drawtext_cr (cairo_t *cr, const char *text, double x, double y, double size)
 {
+	if(*text) {
   //use the FreeSerif font as it has music symbols - there is no font substitution done by cairo here
   cairo_select_font_face( cr, "Denemo", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL );
   cairo_set_font_size( cr, size );
   cairo_move_to( cr, x,y );
-  cairo_show_text( cr, text );
-
+  cairo_show_text( cr, text);
+ }
 }
 void drawnormaltext_cr (cairo_t *cr, const char *text, double x, double y)
 {
@@ -318,7 +325,7 @@ void drawlargetext_cr (cairo_t *cr, const char *text, double x, double y)
 
 /* draw display text and or graphics for directives
  return the widest graphic width*/
-gint   draw_for_directives(cairo_t * cr, GList *directives, gint x, gint y) {
+gint   draw_for_directives(cairo_t * cr, GList *directives, gint x, gint y, gboolean at_cursor) {
  gint count=10;
  gint maxwidth=0;
   for(;directives;directives=directives->next, count+=10) {
@@ -335,8 +342,21 @@ gint   draw_for_directives(cairo_t * cr, GList *directives, gint x, gint y) {
       
     }
     if(directive->display) {
+#define MAXLEN (8)
+			gchar c=0;//if it is a long string only show it all when cursor is on it also only display from first line
+			gchar *p;
+			for(p=directive->display->str;*p;p++) {
+				if(*p=='\n' || (!at_cursor && (p-directive->display->str)>MAXLEN)) {
+					c=*p;
+					*p=0;
+					break;
+				}
+			}
       drawnormaltext_cr (cr, directive->display->str, x+directive->tx+count, y+directive->ty ); 
-    }
+			if(c) {
+			*p = c;      
+			}
+		}
   }
 
   return maxwidth;
@@ -899,7 +919,7 @@ get_data_dir ()
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
-#ifdef UNUSED__APPLE
+#ifdef _MACH_O_
      
       {char path[1024];
        guint size = sizeof(path);
@@ -912,14 +932,36 @@ get_data_dir ()
        datadir = g_build_filename (g_path_get_dirname(bindir), "..", "share", "denemo", NULL);
        g_print("OSX set data dir to %s\n", datadir);
       }
+#else
+#ifndef ENABLE_BINRELOC
+    datadir = g_strdup (PKGDATADIR);
 #else
     datadir = gbr_find_pkg_data_dir (PKGDATADIR, PKGNAME);
-#endif
+#endif //ENABLE_BINRELOC
+
+#endif //_MACH_O_
 #endif /* not G_OS_WIN32 */
   }
   return datadir;
 }
 
+const gchar *
+get_prefix_dir (void)
+{
+#ifdef G_OS_WIN32 //THis is going to need to be tested
+    gchar *prefix = g_win32_get_package_installation_directory (NULL, NULL);
+#else /* not G_OS_WIN32 */
+
+#ifndef ENABLE_BINRELOC
+  gchar *prefix = g_strdup (PREFIX);
+#else
+  gchar *prefix = gbr_find_prefix (PREFIX);
+#endif //ENABLE_BINRELOC
+#endif //G_OS_WIN32
+  g_print ("prefix=%s\n", prefix);
+  return prefix;
+}
+
 const gchar *
 get_bin_dir (void)
 {
@@ -934,7 +976,7 @@ get_bin_dir (void)
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
-#ifdef UNUSED__APPLE
+#ifdef _MACH_O_
      
       {char path[1024];
        guint size = sizeof(path);
@@ -948,8 +990,14 @@ get_bin_dir (void)
        g_print("OSX set bin dir to %s\n", bindir);
       }
 #else
-    bindir = gbr_find_bin_dir ("/usr/local/bin");
-#endif
+
+#ifndef ENABLE_BINRELOC
+  bindir = g_strdup (BINDIR);
+#else
+  bindir = gbr_find_bin_dir (BINDIR);
+#endif //ENABLE_BINRELOC
+
+#endif //_MACH_O_
 #endif /* not G_OS_WIN32 */
   }
   return bindir;
@@ -966,7 +1014,7 @@ get_conf_dir ()
   confdir = g_build_filename (rootdir, "etc", "denemo", NULL);
   g_free (rootdir);
 #else /* not G_OS_WIN32 */
-#ifdef UNUSED__APPLE
+#ifdef _MACH_O_
      
       {char path[1024];
        guint size = sizeof(path);
@@ -980,8 +1028,14 @@ get_conf_dir ()
        g_print("OSX set conf dir to %s\n", confdir);
       }
 #else
-  confdir = gbr_find_etc_dir(SYSCONFDIR);
-#endif
+
+#ifndef ENABLE_BINRELOC
+  confdir = g_build_filename (SYSCONFDIR, NULL);
+#else
+  confdir = g_build_filename (gbr_find_etc_dir(SYSCONFDIR), "denemo", NULL);
+#endif //ENABLE_BINRELOC
+
+#endif //_MACH_O_
 #endif /* not G_OS_WIN32 */
   }
   return confdir;
@@ -998,7 +1052,7 @@ get_locale_dir ()
     localedir = g_build_filename (rootdir, "share", "locale", NULL);
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
-#ifdef UNUSED__APPLE
+#ifdef _MACH_O_
      
       {char path[1024];
        guint size = sizeof(path);
@@ -1198,7 +1252,7 @@ void  set_title_bar(DenemoGUI *gui) {
   if(gui->tabname && gui->tabname->len)
     title = gui->tabname->str;
   else
-    title = "(Untitled)";
+    title = _("(Untitled)");
   title = g_strdup_printf("%s%c", title, gui->notsaved?'*':' ');
   gtk_window_set_title (GTK_WINDOW (Denemo.window), title); 
   gchar *base = g_path_get_basename (title);
@@ -1219,7 +1273,7 @@ switch(enshift) {
     case 0: return " ";
     case 1: return "♯";
     case 2: return "𝄪";
-    default: return "Error";
+    default: return _("Error");
 }
 }
 /* set the status of the current musical score - its change count and
@@ -1445,7 +1499,6 @@ string_dialog_entry_with_widget_opt (DenemoGUI *gui, gchar *wlabel, gchar *direc
                                         (GtkDialogFlags) (GTK_DIALOG_DESTROY_WITH_PARENT),
                                         GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                         NULL);
-
 	label = gtk_label_new (direction);
 	GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_container_add(GTK_CONTAINER(content_area), label);
@@ -1468,24 +1521,25 @@ string_dialog_entry_with_widget_opt (DenemoGUI *gui, gchar *wlabel, gchar *direc
   
   if(modal) {
     gtk_widget_grab_focus (entry);
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT){ 
-		entry_string = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
-		string = g_string_new(entry_string);
-		gtk_widget_destroy (dialog);
-		return g_string_free(string, FALSE);
-	}
-	else {  
-		gtk_widget_destroy (dialog);
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT){ 
+			entry_string = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
+			string = g_string_new(entry_string);
+			gtk_widget_destroy (dialog);
+			return g_string_free(string, FALSE);
+		}	else {  
+			gtk_widget_destroy (dialog);
+			return NULL;
+		}
 		return NULL;
-	}
-  return NULL;
   } else {
     g_signal_connect_swapped (dialog,"response", G_CALLBACK (gtk_main_quit), entry);
     gtk_main();
-    entry_string = (gchar *) gtk_entry_get_text (GTK_ENTRY (entry));
-		string = g_string_new(entry_string);
-    gtk_widget_destroy (dialog);
-		return g_string_free(string, FALSE);
+    if( GTK_IS_WIDGET(entry)) {
+			entry_string = GTK_IS_WIDGET(entry)?	g_strdup((gchar *) gtk_entry_get_text (GTK_ENTRY (entry))):NULL;
+			gtk_widget_destroy (dialog);
+			return entry_string;
+		}
+		return NULL;
   }
 }
 
@@ -1535,30 +1589,35 @@ string_dialog_editor_with_widget_opt (DenemoGUI *gui, gchar *wlabel, gchar *dire
   
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_keep_above(GTK_WINDOW (dialog), TRUE);
-  gtk_widget_show_all (dialog);
+  gtk_widget_show_all (dialog); 
+  gtk_widget_grab_focus (textview);  
   if(modal) {
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT){
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT){
       GtkTextIter startiter, enditer;
       gtk_text_buffer_get_start_iter (textbuffer, &startiter);
       gtk_text_buffer_get_end_iter (textbuffer, &enditer);
       gchar *text = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, FALSE);
       gtk_widget_destroy (dialog);
       return  text;
-	}
-	else {  
+		}
+		else {  
 		gtk_widget_destroy (dialog);
 		return NULL;
-	}
-  return NULL;
+		}
+		return NULL;
   } else {
     g_signal_connect_swapped (dialog,"response", G_CALLBACK (gtk_main_quit), NULL);
     gtk_main();
-    GtkTextIter startiter, enditer;
-    gtk_text_buffer_get_start_iter (textbuffer, &startiter);
-    gtk_text_buffer_get_end_iter (textbuffer, &enditer);
-    gchar *text = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, FALSE);
-    gtk_widget_destroy (dialog);
-		return text;
+    if(GTK_IS_TEXT_BUFFER(textbuffer)) {
+			GtkTextIter startiter, enditer;
+			gtk_text_buffer_get_start_iter (textbuffer, &startiter);
+			gtk_text_buffer_get_end_iter (textbuffer, &enditer);
+			gchar *text = gtk_text_buffer_get_text (textbuffer, &startiter, &enditer, FALSE);
+			gtk_widget_destroy (dialog);
+			return text;
+		} else {
+			return NULL;
+		}
   }
 }
 
